Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitaly.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPatrick Bajao <ebajao@gitlab.com>2019-04-01 21:30:42 +0300
committerPaul Okstad <pokstad@gitlab.com>2019-04-01 21:30:42 +0300
commit08bf09bae9e5793d2dc1f129760189abcf0f6fe4 (patch)
tree43d1a92dd63b5ae300b3a8fd788092a3c216c95f
parent071db2de108f6fd3ebcce81e1f8270d8a582dba5 (diff)
Accept Path option for GetArchive RPC
Updates the GetArchive RPC to accept a `Path` option. This option will be used when calling `git archive` for archiving a directory in a repository.
-rw-r--r--changelogs/unreleased/24704-get-archive-by-path.yml5
-rw-r--r--internal/helper/error.go16
-rw-r--r--internal/service/repository/archive.go93
-rw-r--r--internal/service/repository/archive_test.go68
-rw-r--r--internal/service/repository/server.go2
-rw-r--r--vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/repository-service.pb.go509
-rw-r--r--vendor/vendor.json10
7 files changed, 421 insertions, 282 deletions
diff --git a/changelogs/unreleased/24704-get-archive-by-path.yml b/changelogs/unreleased/24704-get-archive-by-path.yml
new file mode 100644
index 000000000..9defd3fb6
--- /dev/null
+++ b/changelogs/unreleased/24704-get-archive-by-path.yml
@@ -0,0 +1,5 @@
+---
+title: Accept Path option for GetArchive RPC
+merge_request: 1142
+author:
+type: added
diff --git a/internal/service/repository/archive.go b/internal/service/repository/archive.go
index 0b871226b..2848910f7 100644
--- a/internal/service/repository/archive.go
+++ b/internal/service/repository/archive.go
@@ -4,15 +4,37 @@ import (
"context"
"io"
"os/exec"
+ "strings"
"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
"gitlab.com/gitlab-org/gitaly/internal/command"
"gitlab.com/gitlab-org/gitaly/internal/git"
+ "gitlab.com/gitlab-org/gitaly/internal/git/catfile"
+ "gitlab.com/gitlab-org/gitaly/internal/helper"
+ "gitlab.com/gitlab-org/gitaly/internal/service/commit"
"gitlab.com/gitlab-org/gitaly/streamio"
- "google.golang.org/grpc/codes"
- "google.golang.org/grpc/status"
)
+func (s *server) GetArchive(in *gitalypb.GetArchiveRequest, stream gitalypb.RepositoryService_GetArchiveServer) error {
+ ctx := stream.Context()
+ compressCmd, format := parseArchiveFormat(in.GetFormat())
+ path := parsePath(in.GetPath())
+
+ if err := validateGetArchiveRequest(in, format, path); err != nil {
+ return err
+ }
+
+ if err := validateGetArchivePrecondition(ctx, in, path); err != nil {
+ return err
+ }
+
+ writer := streamio.NewWriter(func(p []byte) error {
+ return stream.Send(&gitalypb.GetArchiveResponse{Data: p})
+ })
+
+ return handleArchive(ctx, writer, in, compressCmd, format, path)
+}
+
func parseArchiveFormat(format gitalypb.GetArchiveRequest_Format) (*exec.Cmd, string) {
switch format {
case gitalypb.GetArchiveRequest_TAR:
@@ -28,15 +50,56 @@ func parseArchiveFormat(format gitalypb.GetArchiveRequest_Format) (*exec.Cmd, st
return nil, ""
}
-func handleArchive(ctx context.Context, writer io.Writer, repo *gitalypb.Repository,
- format gitalypb.GetArchiveRequest_Format, prefix, commitID string) error {
- compressCmd, formatArg := parseArchiveFormat(format)
- if len(formatArg) == 0 {
- return status.Errorf(codes.InvalidArgument, "invalid format")
+func parsePath(path []byte) string {
+ if path == nil {
+ return "."
+ }
+
+ return string(path)
+}
+
+func validateGetArchiveRequest(in *gitalypb.GetArchiveRequest, format string, path string) error {
+ if err := git.ValidateRevision([]byte(in.GetCommitId())); err != nil {
+ return helper.ErrInvalidArgumentf("invalid commitId: %v", err)
+ }
+
+ if len(format) == 0 {
+ return helper.ErrInvalidArgumentf("invalid format")
+ }
+
+ if helper.ContainsPathTraversal(path) {
+ return helper.ErrInvalidArgumentf("path can't contain directory traversal")
+ }
+
+ return nil
+}
+
+func validateGetArchivePrecondition(ctx context.Context, in *gitalypb.GetArchiveRequest, path string) error {
+ if path == "." {
+ return nil
+ }
+
+ c, err := catfile.New(ctx, in.GetRepository())
+ if err != nil {
+ return err
+ }
+
+ treeEntry, err := commit.TreeEntryForRevisionAndPath(c, in.GetCommitId(), strings.TrimRight(path, "/"))
+ if err != nil {
+ return err
+ }
+
+ if treeEntry == nil || len(treeEntry.Oid) == 0 {
+ return helper.ErrPreconditionFailedf("path doesn't exist")
}
- archiveCommand, err := git.Command(ctx, repo, "archive",
- "--format="+formatArg, "--prefix="+prefix+"/", commitID)
+ return nil
+}
+
+func handleArchive(ctx context.Context, writer io.Writer, in *gitalypb.GetArchiveRequest, compressCmd *exec.Cmd, format string, path string) error {
+ archiveCommand, err := git.Command(ctx, in.GetRepository(), "archive",
+ "--format="+format, "--prefix="+in.GetPrefix()+"/", in.GetCommitId(), path)
+
if err != nil {
return err
}
@@ -56,15 +119,3 @@ func handleArchive(ctx context.Context, writer io.Writer, repo *gitalypb.Reposit
return archiveCommand.Wait()
}
-
-func (s *server) GetArchive(in *gitalypb.GetArchiveRequest, stream gitalypb.RepositoryService_GetArchiveServer) error {
- if err := git.ValidateRevision([]byte(in.CommitId)); err != nil {
- return status.Errorf(codes.InvalidArgument, "invalid commitId: %v", err)
- }
-
- writer := streamio.NewWriter(func(p []byte) error {
- return stream.Send(&gitalypb.GetArchiveResponse{Data: p})
- })
-
- return handleArchive(stream.Context(), writer, in.Repository, in.Format, in.Prefix, in.CommitId)
-}
diff --git a/internal/service/repository/archive_test.go b/internal/service/repository/archive_test.go
index e0ba5ff9e..b8d43c980 100644
--- a/internal/service/repository/archive_test.go
+++ b/internal/service/repository/archive_test.go
@@ -34,16 +34,48 @@ func TestGetArchiveSuccess(t *testing.T) {
desc string
prefix string
commitID string
+ path []byte
+ contents []string
}{
{
desc: "without-prefix",
commitID: "1a0b36b3cdad1d2ee32457c102a8c0b7056fa863",
prefix: "",
+ contents: []string{"/.gitignore", "/LICENSE", "/README.md"},
},
{
desc: "with-prefix",
commitID: "1a0b36b3cdad1d2ee32457c102a8c0b7056fa863",
prefix: "my-prefix",
+ contents: []string{"/.gitignore", "/LICENSE", "/README.md"},
+ },
+ {
+ desc: "with path as blank string",
+ commitID: "1e292f8fedd741b75372e19097c76d327140c312",
+ prefix: "",
+ path: []byte(""),
+ contents: []string{"/.gitignore", "/LICENSE", "/README.md"},
+ },
+ {
+ desc: "with path as nil",
+ commitID: "1e292f8fedd741b75372e19097c76d327140c312",
+ prefix: "",
+ path: nil,
+ contents: []string{"/.gitignore", "/LICENSE", "/README.md"},
+ },
+ {
+ desc: "with path",
+ commitID: "1e292f8fedd741b75372e19097c76d327140c312",
+ prefix: "",
+ path: []byte("files"),
+ contents: []string{"/whitespace", "/html/500.html"},
+ },
+ {
+ desc: "with path and trailing slash",
+ commitID: "1e292f8fedd741b75372e19097c76d327140c312",
+ prefix: "",
+ path: []byte("files/"),
+ contents: []string{"/whitespace", "/html/500.html"},
},
}
@@ -60,6 +92,7 @@ func TestGetArchiveSuccess(t *testing.T) {
CommitId: tc.commitID,
Prefix: tc.prefix,
Format: format,
+ Path: tc.path,
}
stream, err := client.GetArchive(ctx, req)
require.NoError(t, err)
@@ -76,9 +109,9 @@ func TestGetArchiveSuccess(t *testing.T) {
contents := string(compressedFileContents(t, format, archiveFile.Name()))
- require.Contains(t, contents, tc.prefix+"/.gitignore")
- require.Contains(t, contents, tc.prefix+"/LICENSE")
- require.Contains(t, contents, tc.prefix+"/README.md")
+ for _, content := range tc.contents {
+ require.Contains(t, contents, tc.prefix+content)
+ }
})
}
}
@@ -102,6 +135,7 @@ func TestGetArchiveFailure(t *testing.T) {
prefix string
commitID string
format gitalypb.GetArchiveRequest_Format
+ path []byte
code codes.Code
}{
{
@@ -136,6 +170,33 @@ func TestGetArchiveFailure(t *testing.T) {
format: gitalypb.GetArchiveRequest_Format(-1),
code: codes.InvalidArgument,
},
+ {
+ desc: "Non-existing path in repository",
+ repo: testRepo,
+ prefix: "",
+ commitID: "1e292f8fedd741b75372e19097c76d327140c312",
+ format: gitalypb.GetArchiveRequest_ZIP,
+ path: []byte("unknown-path"),
+ code: codes.FailedPrecondition,
+ },
+ {
+ desc: "Non-existing path in repository on commit ID",
+ repo: testRepo,
+ prefix: "",
+ commitID: commitID,
+ format: gitalypb.GetArchiveRequest_ZIP,
+ path: []byte("files/"),
+ code: codes.FailedPrecondition,
+ },
+ {
+ desc: "path contains directory traversal",
+ repo: testRepo,
+ prefix: "",
+ commitID: "1e292f8fedd741b75372e19097c76d327140c312",
+ format: gitalypb.GetArchiveRequest_ZIP,
+ path: []byte("../../foo"),
+ code: codes.InvalidArgument,
+ },
}
for _, tc := range testCases {
@@ -148,6 +209,7 @@ func TestGetArchiveFailure(t *testing.T) {
CommitId: tc.commitID,
Prefix: tc.prefix,
Format: tc.format,
+ Path: tc.path,
}
stream, err := client.GetArchive(ctx, req)
require.NoError(t, err)
diff --git a/internal/service/repository/server.go b/internal/service/repository/server.go
index 95717018d..a4a0355e9 100644
--- a/internal/service/repository/server.go
+++ b/internal/service/repository/server.go
@@ -17,6 +17,6 @@ func NewServer(rs *rubyserver.Server) gitalypb.RepositoryServiceServer {
return &server{Server: rs}
}
-func (s *server) FetchHTTPRemote(ctx context.Context, req *gitalypb.FetchHTTPRemoteRequest) (*gitalypb.FetchHTTPRemoteResponse, error) {
+func (*server) FetchHTTPRemote(context.Context, *gitalypb.FetchHTTPRemoteRequest) (*gitalypb.FetchHTTPRemoteResponse, error) {
return nil, helper.Unimplemented
}
diff --git a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/repository-service.pb.go b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/repository-service.pb.go
index 7c29c7813..77710e1a9 100644
--- a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/repository-service.pb.go
+++ b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/repository-service.pb.go
@@ -49,7 +49,7 @@ func (x GetArchiveRequest_Format) String() string {
return proto.EnumName(GetArchiveRequest_Format_name, int32(x))
}
func (GetArchiveRequest_Format) EnumDescriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{18, 0}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{18, 0}
}
type GetRawChangesResponse_RawChange_Operation int32
@@ -87,7 +87,7 @@ func (x GetRawChangesResponse_RawChange_Operation) String() string {
return proto.EnumName(GetRawChangesResponse_RawChange_Operation_name, int32(x))
}
func (GetRawChangesResponse_RawChange_Operation) EnumDescriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{63, 0, 0}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{63, 0, 0}
}
type RepositoryExistsRequest struct {
@@ -101,7 +101,7 @@ func (m *RepositoryExistsRequest) Reset() { *m = RepositoryExistsRequest
func (m *RepositoryExistsRequest) String() string { return proto.CompactTextString(m) }
func (*RepositoryExistsRequest) ProtoMessage() {}
func (*RepositoryExistsRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{0}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{0}
}
func (m *RepositoryExistsRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepositoryExistsRequest.Unmarshal(m, b)
@@ -139,7 +139,7 @@ func (m *RepositoryExistsResponse) Reset() { *m = RepositoryExistsRespon
func (m *RepositoryExistsResponse) String() string { return proto.CompactTextString(m) }
func (*RepositoryExistsResponse) ProtoMessage() {}
func (*RepositoryExistsResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{1}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{1}
}
func (m *RepositoryExistsResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepositoryExistsResponse.Unmarshal(m, b)
@@ -177,7 +177,7 @@ func (m *RepackIncrementalRequest) Reset() { *m = RepackIncrementalReque
func (m *RepackIncrementalRequest) String() string { return proto.CompactTextString(m) }
func (*RepackIncrementalRequest) ProtoMessage() {}
func (*RepackIncrementalRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{2}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{2}
}
func (m *RepackIncrementalRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepackIncrementalRequest.Unmarshal(m, b)
@@ -214,7 +214,7 @@ func (m *RepackIncrementalResponse) Reset() { *m = RepackIncrementalResp
func (m *RepackIncrementalResponse) String() string { return proto.CompactTextString(m) }
func (*RepackIncrementalResponse) ProtoMessage() {}
func (*RepackIncrementalResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{3}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{3}
}
func (m *RepackIncrementalResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepackIncrementalResponse.Unmarshal(m, b)
@@ -246,7 +246,7 @@ func (m *RepackFullRequest) Reset() { *m = RepackFullRequest{} }
func (m *RepackFullRequest) String() string { return proto.CompactTextString(m) }
func (*RepackFullRequest) ProtoMessage() {}
func (*RepackFullRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{4}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{4}
}
func (m *RepackFullRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepackFullRequest.Unmarshal(m, b)
@@ -290,7 +290,7 @@ func (m *RepackFullResponse) Reset() { *m = RepackFullResponse{} }
func (m *RepackFullResponse) String() string { return proto.CompactTextString(m) }
func (*RepackFullResponse) ProtoMessage() {}
func (*RepackFullResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{5}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{5}
}
func (m *RepackFullResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepackFullResponse.Unmarshal(m, b)
@@ -322,7 +322,7 @@ func (m *GarbageCollectRequest) Reset() { *m = GarbageCollectRequest{} }
func (m *GarbageCollectRequest) String() string { return proto.CompactTextString(m) }
func (*GarbageCollectRequest) ProtoMessage() {}
func (*GarbageCollectRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{6}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{6}
}
func (m *GarbageCollectRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GarbageCollectRequest.Unmarshal(m, b)
@@ -366,7 +366,7 @@ func (m *GarbageCollectResponse) Reset() { *m = GarbageCollectResponse{}
func (m *GarbageCollectResponse) String() string { return proto.CompactTextString(m) }
func (*GarbageCollectResponse) ProtoMessage() {}
func (*GarbageCollectResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{7}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{7}
}
func (m *GarbageCollectResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GarbageCollectResponse.Unmarshal(m, b)
@@ -397,7 +397,7 @@ func (m *CleanupRequest) Reset() { *m = CleanupRequest{} }
func (m *CleanupRequest) String() string { return proto.CompactTextString(m) }
func (*CleanupRequest) ProtoMessage() {}
func (*CleanupRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{8}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{8}
}
func (m *CleanupRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CleanupRequest.Unmarshal(m, b)
@@ -434,7 +434,7 @@ func (m *CleanupResponse) Reset() { *m = CleanupResponse{} }
func (m *CleanupResponse) String() string { return proto.CompactTextString(m) }
func (*CleanupResponse) ProtoMessage() {}
func (*CleanupResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{9}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{9}
}
func (m *CleanupResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CleanupResponse.Unmarshal(m, b)
@@ -465,7 +465,7 @@ func (m *RepositorySizeRequest) Reset() { *m = RepositorySizeRequest{} }
func (m *RepositorySizeRequest) String() string { return proto.CompactTextString(m) }
func (*RepositorySizeRequest) ProtoMessage() {}
func (*RepositorySizeRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{10}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{10}
}
func (m *RepositorySizeRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepositorySizeRequest.Unmarshal(m, b)
@@ -504,7 +504,7 @@ func (m *RepositorySizeResponse) Reset() { *m = RepositorySizeResponse{}
func (m *RepositorySizeResponse) String() string { return proto.CompactTextString(m) }
func (*RepositorySizeResponse) ProtoMessage() {}
func (*RepositorySizeResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{11}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{11}
}
func (m *RepositorySizeResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RepositorySizeResponse.Unmarshal(m, b)
@@ -543,7 +543,7 @@ func (m *ApplyGitattributesRequest) Reset() { *m = ApplyGitattributesReq
func (m *ApplyGitattributesRequest) String() string { return proto.CompactTextString(m) }
func (*ApplyGitattributesRequest) ProtoMessage() {}
func (*ApplyGitattributesRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{12}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{12}
}
func (m *ApplyGitattributesRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_ApplyGitattributesRequest.Unmarshal(m, b)
@@ -587,7 +587,7 @@ func (m *ApplyGitattributesResponse) Reset() { *m = ApplyGitattributesRe
func (m *ApplyGitattributesResponse) String() string { return proto.CompactTextString(m) }
func (*ApplyGitattributesResponse) ProtoMessage() {}
func (*ApplyGitattributesResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{13}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{13}
}
func (m *ApplyGitattributesResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_ApplyGitattributesResponse.Unmarshal(m, b)
@@ -625,7 +625,7 @@ func (m *FetchRemoteRequest) Reset() { *m = FetchRemoteRequest{} }
func (m *FetchRemoteRequest) String() string { return proto.CompactTextString(m) }
func (*FetchRemoteRequest) ProtoMessage() {}
func (*FetchRemoteRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{14}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{14}
}
func (m *FetchRemoteRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FetchRemoteRequest.Unmarshal(m, b)
@@ -711,7 +711,7 @@ func (m *FetchRemoteResponse) Reset() { *m = FetchRemoteResponse{} }
func (m *FetchRemoteResponse) String() string { return proto.CompactTextString(m) }
func (*FetchRemoteResponse) ProtoMessage() {}
func (*FetchRemoteResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{15}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{15}
}
func (m *FetchRemoteResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FetchRemoteResponse.Unmarshal(m, b)
@@ -742,7 +742,7 @@ func (m *CreateRepositoryRequest) Reset() { *m = CreateRepositoryRequest
func (m *CreateRepositoryRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryRequest) ProtoMessage() {}
func (*CreateRepositoryRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{16}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{16}
}
func (m *CreateRepositoryRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryRequest.Unmarshal(m, b)
@@ -779,7 +779,7 @@ func (m *CreateRepositoryResponse) Reset() { *m = CreateRepositoryRespon
func (m *CreateRepositoryResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryResponse) ProtoMessage() {}
func (*CreateRepositoryResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{17}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{17}
}
func (m *CreateRepositoryResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryResponse.Unmarshal(m, b)
@@ -804,6 +804,7 @@ type GetArchiveRequest struct {
CommitId string `protobuf:"bytes,2,opt,name=commit_id,json=commitId,proto3" json:"commit_id,omitempty"`
Prefix string `protobuf:"bytes,3,opt,name=prefix,proto3" json:"prefix,omitempty"`
Format GetArchiveRequest_Format `protobuf:"varint,4,opt,name=format,proto3,enum=gitaly.GetArchiveRequest_Format" json:"format,omitempty"`
+ Path []byte `protobuf:"bytes,5,opt,name=path,proto3" json:"path,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
@@ -813,7 +814,7 @@ func (m *GetArchiveRequest) Reset() { *m = GetArchiveRequest{} }
func (m *GetArchiveRequest) String() string { return proto.CompactTextString(m) }
func (*GetArchiveRequest) ProtoMessage() {}
func (*GetArchiveRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{18}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{18}
}
func (m *GetArchiveRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetArchiveRequest.Unmarshal(m, b)
@@ -861,6 +862,13 @@ func (m *GetArchiveRequest) GetFormat() GetArchiveRequest_Format {
return GetArchiveRequest_ZIP
}
+func (m *GetArchiveRequest) GetPath() []byte {
+ if m != nil {
+ return m.Path
+ }
+ return nil
+}
+
type GetArchiveResponse struct {
Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
@@ -872,7 +880,7 @@ func (m *GetArchiveResponse) Reset() { *m = GetArchiveResponse{} }
func (m *GetArchiveResponse) String() string { return proto.CompactTextString(m) }
func (*GetArchiveResponse) ProtoMessage() {}
func (*GetArchiveResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{19}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{19}
}
func (m *GetArchiveResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetArchiveResponse.Unmarshal(m, b)
@@ -910,7 +918,7 @@ func (m *HasLocalBranchesRequest) Reset() { *m = HasLocalBranchesRequest
func (m *HasLocalBranchesRequest) String() string { return proto.CompactTextString(m) }
func (*HasLocalBranchesRequest) ProtoMessage() {}
func (*HasLocalBranchesRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{20}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{20}
}
func (m *HasLocalBranchesRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_HasLocalBranchesRequest.Unmarshal(m, b)
@@ -948,7 +956,7 @@ func (m *HasLocalBranchesResponse) Reset() { *m = HasLocalBranchesRespon
func (m *HasLocalBranchesResponse) String() string { return proto.CompactTextString(m) }
func (*HasLocalBranchesResponse) ProtoMessage() {}
func (*HasLocalBranchesResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{21}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{21}
}
func (m *HasLocalBranchesResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_HasLocalBranchesResponse.Unmarshal(m, b)
@@ -989,7 +997,7 @@ func (m *FetchSourceBranchRequest) Reset() { *m = FetchSourceBranchReque
func (m *FetchSourceBranchRequest) String() string { return proto.CompactTextString(m) }
func (*FetchSourceBranchRequest) ProtoMessage() {}
func (*FetchSourceBranchRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{22}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{22}
}
func (m *FetchSourceBranchRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FetchSourceBranchRequest.Unmarshal(m, b)
@@ -1048,7 +1056,7 @@ func (m *FetchSourceBranchResponse) Reset() { *m = FetchSourceBranchResp
func (m *FetchSourceBranchResponse) String() string { return proto.CompactTextString(m) }
func (*FetchSourceBranchResponse) ProtoMessage() {}
func (*FetchSourceBranchResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{23}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{23}
}
func (m *FetchSourceBranchResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FetchSourceBranchResponse.Unmarshal(m, b)
@@ -1086,7 +1094,7 @@ func (m *FsckRequest) Reset() { *m = FsckRequest{} }
func (m *FsckRequest) String() string { return proto.CompactTextString(m) }
func (*FsckRequest) ProtoMessage() {}
func (*FsckRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{24}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{24}
}
func (m *FsckRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FsckRequest.Unmarshal(m, b)
@@ -1124,7 +1132,7 @@ func (m *FsckResponse) Reset() { *m = FsckResponse{} }
func (m *FsckResponse) String() string { return proto.CompactTextString(m) }
func (*FsckResponse) ProtoMessage() {}
func (*FsckResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{25}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{25}
}
func (m *FsckResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FsckResponse.Unmarshal(m, b)
@@ -1166,7 +1174,7 @@ func (m *WriteRefRequest) Reset() { *m = WriteRefRequest{} }
func (m *WriteRefRequest) String() string { return proto.CompactTextString(m) }
func (*WriteRefRequest) ProtoMessage() {}
func (*WriteRefRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{26}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{26}
}
func (m *WriteRefRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_WriteRefRequest.Unmarshal(m, b)
@@ -1231,7 +1239,7 @@ func (m *WriteRefResponse) Reset() { *m = WriteRefResponse{} }
func (m *WriteRefResponse) String() string { return proto.CompactTextString(m) }
func (*WriteRefResponse) ProtoMessage() {}
func (*WriteRefResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{27}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{27}
}
func (m *WriteRefResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_WriteRefResponse.Unmarshal(m, b)
@@ -1266,7 +1274,7 @@ func (m *FindMergeBaseRequest) Reset() { *m = FindMergeBaseRequest{} }
func (m *FindMergeBaseRequest) String() string { return proto.CompactTextString(m) }
func (*FindMergeBaseRequest) ProtoMessage() {}
func (*FindMergeBaseRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{28}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{28}
}
func (m *FindMergeBaseRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FindMergeBaseRequest.Unmarshal(m, b)
@@ -1311,7 +1319,7 @@ func (m *FindMergeBaseResponse) Reset() { *m = FindMergeBaseResponse{} }
func (m *FindMergeBaseResponse) String() string { return proto.CompactTextString(m) }
func (*FindMergeBaseResponse) ProtoMessage() {}
func (*FindMergeBaseResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{29}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{29}
}
func (m *FindMergeBaseResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FindMergeBaseResponse.Unmarshal(m, b)
@@ -1350,7 +1358,7 @@ func (m *CreateForkRequest) Reset() { *m = CreateForkRequest{} }
func (m *CreateForkRequest) String() string { return proto.CompactTextString(m) }
func (*CreateForkRequest) ProtoMessage() {}
func (*CreateForkRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{30}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{30}
}
func (m *CreateForkRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateForkRequest.Unmarshal(m, b)
@@ -1394,7 +1402,7 @@ func (m *CreateForkResponse) Reset() { *m = CreateForkResponse{} }
func (m *CreateForkResponse) String() string { return proto.CompactTextString(m) }
func (*CreateForkResponse) ProtoMessage() {}
func (*CreateForkResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{31}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{31}
}
func (m *CreateForkResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateForkResponse.Unmarshal(m, b)
@@ -1426,7 +1434,7 @@ func (m *IsRebaseInProgressRequest) Reset() { *m = IsRebaseInProgressReq
func (m *IsRebaseInProgressRequest) String() string { return proto.CompactTextString(m) }
func (*IsRebaseInProgressRequest) ProtoMessage() {}
func (*IsRebaseInProgressRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{32}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{32}
}
func (m *IsRebaseInProgressRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_IsRebaseInProgressRequest.Unmarshal(m, b)
@@ -1471,7 +1479,7 @@ func (m *IsRebaseInProgressResponse) Reset() { *m = IsRebaseInProgressRe
func (m *IsRebaseInProgressResponse) String() string { return proto.CompactTextString(m) }
func (*IsRebaseInProgressResponse) ProtoMessage() {}
func (*IsRebaseInProgressResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{33}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{33}
}
func (m *IsRebaseInProgressResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_IsRebaseInProgressResponse.Unmarshal(m, b)
@@ -1510,7 +1518,7 @@ func (m *IsSquashInProgressRequest) Reset() { *m = IsSquashInProgressReq
func (m *IsSquashInProgressRequest) String() string { return proto.CompactTextString(m) }
func (*IsSquashInProgressRequest) ProtoMessage() {}
func (*IsSquashInProgressRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{34}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{34}
}
func (m *IsSquashInProgressRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_IsSquashInProgressRequest.Unmarshal(m, b)
@@ -1555,7 +1563,7 @@ func (m *IsSquashInProgressResponse) Reset() { *m = IsSquashInProgressRe
func (m *IsSquashInProgressResponse) String() string { return proto.CompactTextString(m) }
func (*IsSquashInProgressResponse) ProtoMessage() {}
func (*IsSquashInProgressResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{35}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{35}
}
func (m *IsSquashInProgressResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_IsSquashInProgressResponse.Unmarshal(m, b)
@@ -1594,7 +1602,7 @@ func (m *CreateRepositoryFromURLRequest) Reset() { *m = CreateRepository
func (m *CreateRepositoryFromURLRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromURLRequest) ProtoMessage() {}
func (*CreateRepositoryFromURLRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{36}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{36}
}
func (m *CreateRepositoryFromURLRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryFromURLRequest.Unmarshal(m, b)
@@ -1638,7 +1646,7 @@ func (m *CreateRepositoryFromURLResponse) Reset() { *m = CreateRepositor
func (m *CreateRepositoryFromURLResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromURLResponse) ProtoMessage() {}
func (*CreateRepositoryFromURLResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{37}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{37}
}
func (m *CreateRepositoryFromURLResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryFromURLResponse.Unmarshal(m, b)
@@ -1669,7 +1677,7 @@ func (m *CreateBundleRequest) Reset() { *m = CreateBundleRequest{} }
func (m *CreateBundleRequest) String() string { return proto.CompactTextString(m) }
func (*CreateBundleRequest) ProtoMessage() {}
func (*CreateBundleRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{38}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{38}
}
func (m *CreateBundleRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateBundleRequest.Unmarshal(m, b)
@@ -1707,7 +1715,7 @@ func (m *CreateBundleResponse) Reset() { *m = CreateBundleResponse{} }
func (m *CreateBundleResponse) String() string { return proto.CompactTextString(m) }
func (*CreateBundleResponse) ProtoMessage() {}
func (*CreateBundleResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{39}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{39}
}
func (m *CreateBundleResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateBundleResponse.Unmarshal(m, b)
@@ -1746,7 +1754,7 @@ func (m *WriteConfigRequest) Reset() { *m = WriteConfigRequest{} }
func (m *WriteConfigRequest) String() string { return proto.CompactTextString(m) }
func (*WriteConfigRequest) ProtoMessage() {}
func (*WriteConfigRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{40}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{40}
}
func (m *WriteConfigRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_WriteConfigRequest.Unmarshal(m, b)
@@ -1791,7 +1799,7 @@ func (m *WriteConfigResponse) Reset() { *m = WriteConfigResponse{} }
func (m *WriteConfigResponse) String() string { return proto.CompactTextString(m) }
func (*WriteConfigResponse) ProtoMessage() {}
func (*WriteConfigResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{41}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{41}
}
func (m *WriteConfigResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_WriteConfigResponse.Unmarshal(m, b)
@@ -1830,7 +1838,7 @@ func (m *SetConfigRequest) Reset() { *m = SetConfigRequest{} }
func (m *SetConfigRequest) String() string { return proto.CompactTextString(m) }
func (*SetConfigRequest) ProtoMessage() {}
func (*SetConfigRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{42}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{42}
}
func (m *SetConfigRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_SetConfigRequest.Unmarshal(m, b)
@@ -1880,7 +1888,7 @@ func (m *SetConfigRequest_Entry) Reset() { *m = SetConfigRequest_Entry{}
func (m *SetConfigRequest_Entry) String() string { return proto.CompactTextString(m) }
func (*SetConfigRequest_Entry) ProtoMessage() {}
func (*SetConfigRequest_Entry) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{42, 0}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{42, 0}
}
func (m *SetConfigRequest_Entry) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_SetConfigRequest_Entry.Unmarshal(m, b)
@@ -2050,7 +2058,7 @@ func (m *SetConfigResponse) Reset() { *m = SetConfigResponse{} }
func (m *SetConfigResponse) String() string { return proto.CompactTextString(m) }
func (*SetConfigResponse) ProtoMessage() {}
func (*SetConfigResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{43}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{43}
}
func (m *SetConfigResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_SetConfigResponse.Unmarshal(m, b)
@@ -2082,7 +2090,7 @@ func (m *DeleteConfigRequest) Reset() { *m = DeleteConfigRequest{} }
func (m *DeleteConfigRequest) String() string { return proto.CompactTextString(m) }
func (*DeleteConfigRequest) ProtoMessage() {}
func (*DeleteConfigRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{44}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{44}
}
func (m *DeleteConfigRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_DeleteConfigRequest.Unmarshal(m, b)
@@ -2126,7 +2134,7 @@ func (m *DeleteConfigResponse) Reset() { *m = DeleteConfigResponse{} }
func (m *DeleteConfigResponse) String() string { return proto.CompactTextString(m) }
func (*DeleteConfigResponse) ProtoMessage() {}
func (*DeleteConfigResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{45}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{45}
}
func (m *DeleteConfigResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_DeleteConfigResponse.Unmarshal(m, b)
@@ -2158,7 +2166,7 @@ func (m *RestoreCustomHooksRequest) Reset() { *m = RestoreCustomHooksReq
func (m *RestoreCustomHooksRequest) String() string { return proto.CompactTextString(m) }
func (*RestoreCustomHooksRequest) ProtoMessage() {}
func (*RestoreCustomHooksRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{46}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{46}
}
func (m *RestoreCustomHooksRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RestoreCustomHooksRequest.Unmarshal(m, b)
@@ -2202,7 +2210,7 @@ func (m *RestoreCustomHooksResponse) Reset() { *m = RestoreCustomHooksRe
func (m *RestoreCustomHooksResponse) String() string { return proto.CompactTextString(m) }
func (*RestoreCustomHooksResponse) ProtoMessage() {}
func (*RestoreCustomHooksResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{47}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{47}
}
func (m *RestoreCustomHooksResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_RestoreCustomHooksResponse.Unmarshal(m, b)
@@ -2233,7 +2241,7 @@ func (m *BackupCustomHooksRequest) Reset() { *m = BackupCustomHooksReque
func (m *BackupCustomHooksRequest) String() string { return proto.CompactTextString(m) }
func (*BackupCustomHooksRequest) ProtoMessage() {}
func (*BackupCustomHooksRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{48}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{48}
}
func (m *BackupCustomHooksRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_BackupCustomHooksRequest.Unmarshal(m, b)
@@ -2271,7 +2279,7 @@ func (m *BackupCustomHooksResponse) Reset() { *m = BackupCustomHooksResp
func (m *BackupCustomHooksResponse) String() string { return proto.CompactTextString(m) }
func (*BackupCustomHooksResponse) ProtoMessage() {}
func (*BackupCustomHooksResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{49}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{49}
}
func (m *BackupCustomHooksResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_BackupCustomHooksResponse.Unmarshal(m, b)
@@ -2311,7 +2319,7 @@ func (m *CreateRepositoryFromBundleRequest) Reset() { *m = CreateReposit
func (m *CreateRepositoryFromBundleRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromBundleRequest) ProtoMessage() {}
func (*CreateRepositoryFromBundleRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{50}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{50}
}
func (m *CreateRepositoryFromBundleRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryFromBundleRequest.Unmarshal(m, b)
@@ -2355,7 +2363,7 @@ func (m *CreateRepositoryFromBundleResponse) Reset() { *m = CreateReposi
func (m *CreateRepositoryFromBundleResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromBundleResponse) ProtoMessage() {}
func (*CreateRepositoryFromBundleResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{51}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{51}
}
func (m *CreateRepositoryFromBundleResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryFromBundleResponse.Unmarshal(m, b)
@@ -2386,7 +2394,7 @@ func (m *FindLicenseRequest) Reset() { *m = FindLicenseRequest{} }
func (m *FindLicenseRequest) String() string { return proto.CompactTextString(m) }
func (*FindLicenseRequest) ProtoMessage() {}
func (*FindLicenseRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{52}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{52}
}
func (m *FindLicenseRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FindLicenseRequest.Unmarshal(m, b)
@@ -2424,7 +2432,7 @@ func (m *FindLicenseResponse) Reset() { *m = FindLicenseResponse{} }
func (m *FindLicenseResponse) String() string { return proto.CompactTextString(m) }
func (*FindLicenseResponse) ProtoMessage() {}
func (*FindLicenseResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{53}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{53}
}
func (m *FindLicenseResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FindLicenseResponse.Unmarshal(m, b)
@@ -2462,7 +2470,7 @@ func (m *GetInfoAttributesRequest) Reset() { *m = GetInfoAttributesReque
func (m *GetInfoAttributesRequest) String() string { return proto.CompactTextString(m) }
func (*GetInfoAttributesRequest) ProtoMessage() {}
func (*GetInfoAttributesRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{54}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{54}
}
func (m *GetInfoAttributesRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetInfoAttributesRequest.Unmarshal(m, b)
@@ -2500,7 +2508,7 @@ func (m *GetInfoAttributesResponse) Reset() { *m = GetInfoAttributesResp
func (m *GetInfoAttributesResponse) String() string { return proto.CompactTextString(m) }
func (*GetInfoAttributesResponse) ProtoMessage() {}
func (*GetInfoAttributesResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{55}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{55}
}
func (m *GetInfoAttributesResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetInfoAttributesResponse.Unmarshal(m, b)
@@ -2538,7 +2546,7 @@ func (m *CalculateChecksumRequest) Reset() { *m = CalculateChecksumReque
func (m *CalculateChecksumRequest) String() string { return proto.CompactTextString(m) }
func (*CalculateChecksumRequest) ProtoMessage() {}
func (*CalculateChecksumRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{56}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{56}
}
func (m *CalculateChecksumRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CalculateChecksumRequest.Unmarshal(m, b)
@@ -2576,7 +2584,7 @@ func (m *CalculateChecksumResponse) Reset() { *m = CalculateChecksumResp
func (m *CalculateChecksumResponse) String() string { return proto.CompactTextString(m) }
func (*CalculateChecksumResponse) ProtoMessage() {}
func (*CalculateChecksumResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{57}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{57}
}
func (m *CalculateChecksumResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CalculateChecksumResponse.Unmarshal(m, b)
@@ -2614,7 +2622,7 @@ func (m *GetSnapshotRequest) Reset() { *m = GetSnapshotRequest{} }
func (m *GetSnapshotRequest) String() string { return proto.CompactTextString(m) }
func (*GetSnapshotRequest) ProtoMessage() {}
func (*GetSnapshotRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{58}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{58}
}
func (m *GetSnapshotRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetSnapshotRequest.Unmarshal(m, b)
@@ -2652,7 +2660,7 @@ func (m *GetSnapshotResponse) Reset() { *m = GetSnapshotResponse{} }
func (m *GetSnapshotResponse) String() string { return proto.CompactTextString(m) }
func (*GetSnapshotResponse) ProtoMessage() {}
func (*GetSnapshotResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{59}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{59}
}
func (m *GetSnapshotResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetSnapshotResponse.Unmarshal(m, b)
@@ -2692,7 +2700,7 @@ func (m *CreateRepositoryFromSnapshotRequest) Reset() { *m = CreateRepos
func (m *CreateRepositoryFromSnapshotRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromSnapshotRequest) ProtoMessage() {}
func (*CreateRepositoryFromSnapshotRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{60}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{60}
}
func (m *CreateRepositoryFromSnapshotRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryFromSnapshotRequest.Unmarshal(m, b)
@@ -2743,7 +2751,7 @@ func (m *CreateRepositoryFromSnapshotResponse) Reset() { *m = CreateRepo
func (m *CreateRepositoryFromSnapshotResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromSnapshotResponse) ProtoMessage() {}
func (*CreateRepositoryFromSnapshotResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{61}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{61}
}
func (m *CreateRepositoryFromSnapshotResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_CreateRepositoryFromSnapshotResponse.Unmarshal(m, b)
@@ -2776,7 +2784,7 @@ func (m *GetRawChangesRequest) Reset() { *m = GetRawChangesRequest{} }
func (m *GetRawChangesRequest) String() string { return proto.CompactTextString(m) }
func (*GetRawChangesRequest) ProtoMessage() {}
func (*GetRawChangesRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{62}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{62}
}
func (m *GetRawChangesRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetRawChangesRequest.Unmarshal(m, b)
@@ -2828,7 +2836,7 @@ func (m *GetRawChangesResponse) Reset() { *m = GetRawChangesResponse{} }
func (m *GetRawChangesResponse) String() string { return proto.CompactTextString(m) }
func (*GetRawChangesResponse) ProtoMessage() {}
func (*GetRawChangesResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{63}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{63}
}
func (m *GetRawChangesResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetRawChangesResponse.Unmarshal(m, b)
@@ -2873,7 +2881,7 @@ func (m *GetRawChangesResponse_RawChange) Reset() { *m = GetRawChangesRe
func (m *GetRawChangesResponse_RawChange) String() string { return proto.CompactTextString(m) }
func (*GetRawChangesResponse_RawChange) ProtoMessage() {}
func (*GetRawChangesResponse_RawChange) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{63, 0}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{63, 0}
}
func (m *GetRawChangesResponse_RawChange) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_GetRawChangesResponse_RawChange.Unmarshal(m, b)
@@ -2962,7 +2970,7 @@ func (m *SearchFilesByNameRequest) Reset() { *m = SearchFilesByNameReque
func (m *SearchFilesByNameRequest) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByNameRequest) ProtoMessage() {}
func (*SearchFilesByNameRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{64}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{64}
}
func (m *SearchFilesByNameRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_SearchFilesByNameRequest.Unmarshal(m, b)
@@ -3014,7 +3022,7 @@ func (m *SearchFilesByNameResponse) Reset() { *m = SearchFilesByNameResp
func (m *SearchFilesByNameResponse) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByNameResponse) ProtoMessage() {}
func (*SearchFilesByNameResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{65}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{65}
}
func (m *SearchFilesByNameResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_SearchFilesByNameResponse.Unmarshal(m, b)
@@ -3055,7 +3063,7 @@ func (m *SearchFilesByContentRequest) Reset() { *m = SearchFilesByConten
func (m *SearchFilesByContentRequest) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByContentRequest) ProtoMessage() {}
func (*SearchFilesByContentRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{66}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{66}
}
func (m *SearchFilesByContentRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_SearchFilesByContentRequest.Unmarshal(m, b)
@@ -3116,7 +3124,7 @@ func (m *SearchFilesByContentResponse) Reset() { *m = SearchFilesByConte
func (m *SearchFilesByContentResponse) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByContentResponse) ProtoMessage() {}
func (*SearchFilesByContentResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{67}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{67}
}
func (m *SearchFilesByContentResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_SearchFilesByContentResponse.Unmarshal(m, b)
@@ -3170,7 +3178,7 @@ func (m *PreFetchRequest) Reset() { *m = PreFetchRequest{} }
func (m *PreFetchRequest) String() string { return proto.CompactTextString(m) }
func (*PreFetchRequest) ProtoMessage() {}
func (*PreFetchRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{68}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{68}
}
func (m *PreFetchRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_PreFetchRequest.Unmarshal(m, b)
@@ -3221,7 +3229,7 @@ func (m *PreFetchResponse) Reset() { *m = PreFetchResponse{} }
func (m *PreFetchResponse) String() string { return proto.CompactTextString(m) }
func (*PreFetchResponse) ProtoMessage() {}
func (*PreFetchResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{69}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{69}
}
func (m *PreFetchResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_PreFetchResponse.Unmarshal(m, b)
@@ -3254,7 +3262,7 @@ func (m *Remote) Reset() { *m = Remote{} }
func (m *Remote) String() string { return proto.CompactTextString(m) }
func (*Remote) ProtoMessage() {}
func (*Remote) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{70}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{70}
}
func (m *Remote) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_Remote.Unmarshal(m, b)
@@ -3308,7 +3316,7 @@ func (m *FetchHTTPRemoteRequest) Reset() { *m = FetchHTTPRemoteRequest{}
func (m *FetchHTTPRemoteRequest) String() string { return proto.CompactTextString(m) }
func (*FetchHTTPRemoteRequest) ProtoMessage() {}
func (*FetchHTTPRemoteRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{71}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{71}
}
func (m *FetchHTTPRemoteRequest) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FetchHTTPRemoteRequest.Unmarshal(m, b)
@@ -3359,7 +3367,7 @@ func (m *FetchHTTPRemoteResponse) Reset() { *m = FetchHTTPRemoteResponse
func (m *FetchHTTPRemoteResponse) String() string { return proto.CompactTextString(m) }
func (*FetchHTTPRemoteResponse) ProtoMessage() {}
func (*FetchHTTPRemoteResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_repository_service_31fa3b04395213d1, []int{72}
+ return fileDescriptor_repository_service_99ade1ae2bfb8239, []int{72}
}
func (m *FetchHTTPRemoteResponse) XXX_Unmarshal(b []byte) error {
return xxx_messageInfo_FetchHTTPRemoteResponse.Unmarshal(m, b)
@@ -4972,177 +4980,178 @@ var _RepositoryService_serviceDesc = grpc.ServiceDesc{
}
func init() {
- proto.RegisterFile("repository-service.proto", fileDescriptor_repository_service_31fa3b04395213d1)
-}
-
-var fileDescriptor_repository_service_31fa3b04395213d1 = []byte{
- // 2688 bytes of a gzipped FileDescriptorProto
- 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xc4, 0x5a, 0xdd, 0x72, 0xdb, 0xb8,
- 0xf5, 0x97, 0xfc, 0x25, 0xe9, 0x48, 0x49, 0x64, 0xd8, 0x89, 0x25, 0xe6, 0xc3, 0x09, 0x93, 0xd9,
- 0xcd, 0x7e, 0x39, 0xbb, 0xce, 0xc5, 0x7f, 0x67, 0xff, 0xed, 0x64, 0xfc, 0x6d, 0xef, 0x26, 0xb6,
- 0x97, 0x76, 0x36, 0xd3, 0xcc, 0x76, 0x38, 0x34, 0x05, 0x59, 0x5c, 0x53, 0x84, 0x16, 0x84, 0xe2,
- 0x75, 0x3a, 0xd3, 0xbb, 0xbd, 0xe8, 0x4c, 0x2f, 0xf6, 0xaa, 0x1f, 0xef, 0xd0, 0x27, 0xe8, 0x53,
- 0xf4, 0xbe, 0x4f, 0xd0, 0xdb, 0xf6, 0x05, 0x3a, 0x00, 0x48, 0x80, 0x14, 0x49, 0x35, 0x1d, 0x69,
- 0xb6, 0x77, 0xc4, 0x39, 0xc0, 0xc1, 0xc1, 0x39, 0x07, 0x07, 0x38, 0x3f, 0x10, 0x5a, 0x14, 0x0f,
- 0x48, 0xe8, 0x31, 0x42, 0xaf, 0x3e, 0x09, 0x31, 0x7d, 0xe3, 0xb9, 0x78, 0x6d, 0x40, 0x09, 0x23,
- 0x68, 0xe1, 0xdc, 0x63, 0x8e, 0x7f, 0x65, 0x34, 0xc2, 0x9e, 0x43, 0x71, 0x47, 0x52, 0xcd, 0x97,
- 0xb0, 0x62, 0xa9, 0x11, 0x3b, 0x3f, 0x78, 0x21, 0x0b, 0x2d, 0xfc, 0xfd, 0x10, 0x87, 0x0c, 0xad,
- 0x03, 0x68, 0x61, 0xad, 0xf2, 0xfd, 0xf2, 0xe3, 0xfa, 0x3a, 0x5a, 0x93, 0x52, 0xd6, 0xf4, 0x20,
- 0x2b, 0xd1, 0xeb, 0x8b, 0x85, 0x7f, 0xfe, 0xf1, 0xf1, 0x4c, 0x75, 0xc6, 0x5c, 0x87, 0x56, 0x56,
- 0x6c, 0x38, 0x20, 0x41, 0x88, 0xd1, 0x2d, 0x58, 0xc0, 0x82, 0x22, 0x64, 0x56, 0xad, 0xa8, 0x65,
- 0x7e, 0x23, 0xc6, 0x38, 0xee, 0xc5, 0x41, 0xe0, 0x52, 0xdc, 0xc7, 0x01, 0x73, 0xfc, 0xc9, 0x75,
- 0x29, 0x9b, 0xb7, 0xa1, 0x9d, 0x23, 0x57, 0x2a, 0x63, 0x32, 0x58, 0x94, 0xcc, 0xdd, 0xa1, 0x3f,
- 0xc9, 0x6c, 0xe8, 0x21, 0x5c, 0x73, 0x29, 0x76, 0x18, 0xb6, 0xcf, 0x3c, 0xd6, 0x77, 0x06, 0xad,
- 0x19, 0xb1, 0xb8, 0x86, 0x24, 0x6e, 0x0a, 0x9a, 0x52, 0x69, 0x19, 0x50, 0x72, 0xd6, 0x48, 0x97,
- 0x1f, 0xe0, 0xe6, 0x9e, 0x43, 0xcf, 0x9c, 0x73, 0xbc, 0x45, 0x7c, 0x1f, 0xbb, 0xec, 0x67, 0xd3,
- 0xa7, 0x05, 0xb7, 0x46, 0x67, 0x8e, 0x74, 0x7a, 0x0e, 0xd7, 0xb7, 0x7c, 0xec, 0x04, 0xc3, 0xc1,
- 0x34, 0x5c, 0xb1, 0x08, 0x37, 0x94, 0xb4, 0x68, 0x82, 0x13, 0xb8, 0xa9, 0x07, 0x9d, 0x78, 0x6f,
- 0xf1, 0x34, 0xc2, 0xef, 0x63, 0xb8, 0x35, 0x2a, 0x34, 0x0a, 0x3e, 0x04, 0x73, 0xa1, 0xf7, 0x16,
- 0x0b, 0x79, 0xb3, 0x96, 0xf8, 0x36, 0x43, 0x68, 0x6f, 0x0c, 0x06, 0xfe, 0xd5, 0x9e, 0xc7, 0x1c,
- 0xc6, 0xa8, 0x77, 0x36, 0x64, 0x78, 0x92, 0x5d, 0x80, 0x0c, 0xa8, 0x52, 0xfc, 0xc6, 0x0b, 0x3d,
- 0x12, 0x08, 0xb3, 0x37, 0x2c, 0xd5, 0x56, 0xa6, 0xb8, 0x03, 0x46, 0xde, 0xa4, 0x91, 0x55, 0x7e,
- 0x3f, 0x03, 0x68, 0x17, 0x33, 0xb7, 0x67, 0xe1, 0x3e, 0x61, 0x93, 0xd8, 0x84, 0x6f, 0x37, 0x2a,
- 0x84, 0x08, 0x55, 0x6a, 0x56, 0xd4, 0x42, 0xcb, 0x30, 0xdf, 0x25, 0xd4, 0xc5, 0xad, 0x59, 0x11,
- 0x18, 0xb2, 0x81, 0x56, 0xa0, 0x12, 0x10, 0x9b, 0x39, 0xe7, 0x61, 0x6b, 0x4e, 0xee, 0xce, 0x80,
- 0x9c, 0x3a, 0xe7, 0x21, 0x6a, 0x41, 0x85, 0x79, 0x7d, 0x4c, 0x86, 0xac, 0x35, 0x7f, 0xbf, 0xfc,
- 0x78, 0xde, 0x8a, 0x9b, 0x7c, 0x48, 0x18, 0xf6, 0xec, 0x0b, 0x7c, 0xd5, 0x5a, 0x90, 0x33, 0x84,
- 0x61, 0xef, 0x2b, 0x7c, 0x85, 0x56, 0xa1, 0x7e, 0x11, 0x90, 0xcb, 0xc0, 0xee, 0x11, 0xbe, 0xdb,
- 0x2b, 0x82, 0x09, 0x82, 0xb4, 0xcf, 0x29, 0xa8, 0x0d, 0xd5, 0x80, 0xd8, 0x03, 0x3a, 0x0c, 0x70,
- 0xab, 0x26, 0x66, 0xab, 0x04, 0xe4, 0x98, 0x37, 0x63, 0x33, 0x7d, 0x39, 0x57, 0xad, 0x36, 0x6b,
- 0xe6, 0x4d, 0x58, 0x4a, 0x59, 0x23, 0xb2, 0xd2, 0x4b, 0x58, 0xd9, 0x12, 0xe1, 0x9c, 0x58, 0xfa,
- 0x14, 0xa2, 0xd4, 0x80, 0x56, 0x56, 0x6c, 0x34, 0xe5, 0xbf, 0xca, 0xb0, 0xb8, 0x87, 0xd9, 0x06,
- 0x75, 0x7b, 0xde, 0x9b, 0x89, 0xfc, 0x72, 0x1b, 0x6a, 0x2e, 0xe9, 0xf7, 0x3d, 0x66, 0x7b, 0x9d,
- 0xc8, 0x35, 0x55, 0x49, 0x38, 0xe8, 0x70, 0xa7, 0x0d, 0x28, 0xee, 0x7a, 0x3f, 0x08, 0xef, 0xd4,
- 0xac, 0xa8, 0x85, 0x3e, 0x87, 0x85, 0x2e, 0xa1, 0x7d, 0x87, 0x09, 0xef, 0x5c, 0x5f, 0xbf, 0x1f,
- 0x4f, 0x92, 0xd1, 0x69, 0x6d, 0x57, 0xf4, 0xb3, 0xa2, 0xfe, 0xe6, 0x53, 0x58, 0x90, 0x14, 0x54,
- 0x81, 0xd9, 0xd7, 0x07, 0xc7, 0xcd, 0x12, 0xff, 0x38, 0xdd, 0xb0, 0x9a, 0x65, 0x04, 0xb0, 0x70,
- 0xba, 0x61, 0xd9, 0x7b, 0xaf, 0x9b, 0x33, 0xa8, 0x0e, 0x15, 0xfe, 0xbd, 0xf9, 0x7a, 0xbd, 0x39,
- 0xab, 0xf6, 0xd3, 0x63, 0x40, 0xc9, 0x09, 0xf4, 0x5e, 0xea, 0x38, 0xcc, 0x11, 0xeb, 0x6d, 0x58,
- 0xe2, 0x9b, 0xbb, 0x64, 0xdf, 0x09, 0x9f, 0x13, 0xd7, 0xf1, 0x37, 0xa9, 0x13, 0xb8, 0x3d, 0x3c,
- 0x95, 0xf3, 0xe4, 0x53, 0x68, 0x65, 0xc5, 0x46, 0x6a, 0x2c, 0xc3, 0xfc, 0x1b, 0xc7, 0x1f, 0xe2,
- 0xe8, 0x38, 0x91, 0x0d, 0xf3, 0xef, 0x65, 0x68, 0x89, 0x98, 0x39, 0x21, 0x43, 0xea, 0x62, 0x39,
- 0x6a, 0x12, 0x7f, 0x3d, 0x83, 0xc5, 0x50, 0x88, 0xb2, 0x13, 0x43, 0x67, 0x0a, 0x87, 0x36, 0x65,
- 0x67, 0x2b, 0x95, 0x91, 0x23, 0x01, 0x67, 0x42, 0x19, 0xe1, 0xda, 0x86, 0xd5, 0x08, 0x13, 0x0a,
- 0xa2, 0xbb, 0x00, 0xcc, 0xa1, 0xe7, 0x98, 0xd9, 0x14, 0x77, 0x85, 0x93, 0x1b, 0x56, 0x4d, 0x52,
- 0x2c, 0xdc, 0x55, 0x21, 0xfa, 0x14, 0xda, 0x39, 0x8b, 0xd3, 0x07, 0x2c, 0xc5, 0xe1, 0xd0, 0x67,
- 0xf1, 0x01, 0x2b, 0x5b, 0xe6, 0x01, 0xd4, 0x77, 0x43, 0xf7, 0x62, 0x1a, 0x5b, 0xe4, 0x11, 0x34,
- 0xa4, 0x28, 0xed, 0x03, 0x4c, 0x29, 0xa1, 0x51, 0x2c, 0xc8, 0x86, 0xf9, 0xd7, 0x32, 0xdc, 0x78,
- 0x45, 0x3d, 0xbe, 0x91, 0xba, 0x93, 0x98, 0xbe, 0x09, 0xb3, 0xdc, 0x1a, 0x32, 0x95, 0xf2, 0xcf,
- 0x54, 0x86, 0x9d, 0x4d, 0x67, 0x58, 0xf4, 0x00, 0x1a, 0xc4, 0xef, 0xd8, 0x8a, 0x2f, 0x8d, 0x58,
- 0x27, 0x7e, 0xc7, 0x8a, 0xbb, 0xa8, 0xdc, 0x37, 0x9f, 0xc8, 0x7d, 0x89, 0x9c, 0xb3, 0xd0, 0xac,
- 0x98, 0x2d, 0x68, 0x6a, 0xdd, 0xe5, 0x32, 0xbf, 0x9c, 0xab, 0x96, 0x9b, 0x33, 0xe6, 0x00, 0x96,
- 0x77, 0xbd, 0xa0, 0xf3, 0x02, 0xd3, 0x73, 0xbc, 0xe9, 0x84, 0x13, 0x65, 0x81, 0x3b, 0x50, 0x8b,
- 0x15, 0x0d, 0x5b, 0x33, 0xf7, 0x67, 0xb9, 0xbb, 0x15, 0x41, 0x85, 0xff, 0x47, 0x70, 0x73, 0x64,
- 0x46, 0xbd, 0x05, 0xcf, 0x9c, 0x50, 0x86, 0x7e, 0xcd, 0x12, 0xdf, 0xe6, 0x4f, 0x65, 0x58, 0x94,
- 0xf9, 0x6b, 0x97, 0xd0, 0x8b, 0xff, 0x65, 0xc8, 0x27, 0xef, 0x3b, 0x49, 0x8d, 0xd4, 0xdd, 0xab,
- 0x7d, 0x10, 0x5a, 0x98, 0x2b, 0x7d, 0x10, 0x1c, 0x53, 0x72, 0x4e, 0x71, 0x18, 0x4e, 0x98, 0x52,
- 0xa9, 0x10, 0x97, 0x48, 0xa9, 0x92, 0x70, 0xd0, 0x51, 0xb6, 0xfc, 0x25, 0x18, 0x79, 0xb3, 0x46,
- 0x06, 0x5d, 0x85, 0xba, 0x17, 0xd8, 0x83, 0x88, 0x1c, 0x6d, 0x20, 0xf0, 0x54, 0x47, 0xa9, 0xf4,
- 0xc9, 0xf7, 0x43, 0x27, 0xec, 0x4d, 0x4d, 0xe9, 0x50, 0x88, 0x4b, 0x28, 0x2d, 0x09, 0xa3, 0x4a,
- 0x67, 0x67, 0x7d, 0x57, 0xa5, 0x03, 0xb8, 0x37, 0x7a, 0xa2, 0xed, 0x52, 0xd2, 0x7f, 0x69, 0x3d,
- 0x9f, 0x70, 0x5b, 0x0e, 0xa9, 0x1f, 0xe9, 0xcc, 0x3f, 0x95, 0xbf, 0x1f, 0xc0, 0x6a, 0xe1, 0x7c,
- 0x91, 0xf3, 0xbf, 0x86, 0x25, 0xd9, 0x65, 0x73, 0x18, 0x74, 0xfc, 0xa9, 0xdc, 0xfa, 0x3e, 0x84,
- 0xe5, 0xb4, 0xc8, 0x31, 0xe7, 0x54, 0x1f, 0x90, 0xd8, 0xdd, 0x5b, 0x24, 0xe8, 0x7a, 0xe7, 0x13,
- 0xfa, 0xaf, 0x3b, 0xf4, 0x7d, 0x7b, 0xe0, 0xb0, 0x5e, 0xec, 0x3f, 0x4e, 0x38, 0x76, 0x58, 0x4f,
- 0x19, 0xe4, 0x23, 0x58, 0x4a, 0x4d, 0x37, 0x36, 0x6d, 0xfe, 0x34, 0x03, 0xcd, 0x13, 0xcc, 0x26,
- 0x57, 0xed, 0x73, 0xa8, 0xe0, 0x80, 0x51, 0x0f, 0xcb, 0xd4, 0x52, 0x5f, 0xbf, 0x17, 0x0f, 0x18,
- 0x15, 0xbf, 0xb6, 0x13, 0x30, 0x7a, 0x65, 0xc5, 0xdd, 0x8d, 0x1f, 0xcb, 0x30, 0x2f, 0x48, 0xdc,
- 0xc9, 0xfc, 0x66, 0x27, 0x13, 0x0c, 0xff, 0x44, 0x77, 0xa1, 0x26, 0x8e, 0x58, 0x3b, 0x64, 0x54,
- 0x2e, 0x78, 0xbf, 0x64, 0x55, 0x05, 0xe9, 0x84, 0x51, 0xf4, 0x00, 0xea, 0x92, 0xed, 0x05, 0xec,
- 0xe9, 0xba, 0xc8, 0xce, 0xf3, 0xfb, 0x25, 0x0b, 0x04, 0xf1, 0x80, 0xd3, 0xd0, 0x2a, 0xc8, 0x96,
- 0x7d, 0x46, 0x88, 0x2f, 0xef, 0x99, 0xfb, 0x25, 0x4b, 0x4a, 0xdd, 0x24, 0xc4, 0xdf, 0xac, 0x44,
- 0x47, 0xba, 0xb2, 0xdf, 0x12, 0x2c, 0x26, 0x54, 0x8e, 0x42, 0x08, 0xc3, 0xd2, 0x36, 0xf6, 0xf1,
- 0x34, 0x9c, 0x88, 0x60, 0xee, 0x02, 0x5f, 0x49, 0x33, 0xd5, 0x2c, 0xf1, 0xad, 0xe6, 0xbe, 0x05,
- 0xcb, 0xe9, 0x69, 0xa2, 0xe9, 0x2f, 0x78, 0x5d, 0x19, 0x32, 0x42, 0xf1, 0xd6, 0x30, 0x64, 0xa4,
- 0xbf, 0x4f, 0xc8, 0x45, 0x38, 0xa1, 0x12, 0x22, 0x4e, 0x67, 0x74, 0x9c, 0x26, 0xcb, 0x85, 0xbc,
- 0xc9, 0x22, 0x55, 0xbe, 0x81, 0xd6, 0xa6, 0xe3, 0x5e, 0x0c, 0x07, 0xd3, 0xd1, 0x44, 0xed, 0xa8,
- 0x27, 0xd0, 0xce, 0x91, 0x3b, 0x66, 0x5b, 0x85, 0xf0, 0x20, 0x6f, 0xe3, 0x4f, 0xbc, 0xc7, 0xc7,
- 0xda, 0xe6, 0x11, 0x98, 0xe3, 0x26, 0x8d, 0x6c, 0x74, 0x0c, 0x88, 0x9f, 0xa1, 0xcf, 0x3d, 0x17,
- 0x07, 0xe1, 0x54, 0xf2, 0xcd, 0x16, 0x2c, 0xa5, 0x24, 0x46, 0x76, 0xf9, 0x18, 0x90, 0x2f, 0x49,
- 0x76, 0xd8, 0x23, 0x94, 0xd9, 0x81, 0xd3, 0x8f, 0x4f, 0xe8, 0x66, 0xc4, 0x39, 0xe1, 0x8c, 0x43,
- 0xa7, 0x2f, 0x5c, 0xb7, 0x87, 0xd9, 0x41, 0xd0, 0x25, 0x1b, 0xd3, 0xa8, 0x3d, 0x95, 0x72, 0xff,
- 0x0f, 0xed, 0x1c, 0xb9, 0x91, 0x8a, 0xf7, 0x00, 0x74, 0xd1, 0x19, 0x39, 0x30, 0x41, 0xe1, 0x4a,
- 0x6d, 0x39, 0xbe, 0x3b, 0xf4, 0x1d, 0x86, 0xb7, 0x7a, 0xd8, 0xbd, 0x08, 0x87, 0xfd, 0x69, 0x28,
- 0xf5, 0x7f, 0xd0, 0xce, 0x91, 0x1b, 0x29, 0x65, 0x40, 0xd5, 0x8d, 0x68, 0x91, 0xb5, 0x54, 0x9b,
- 0x3b, 0x6f, 0x0f, 0xb3, 0x93, 0xc0, 0x19, 0x84, 0x3d, 0xc2, 0xa6, 0xa1, 0xca, 0x07, 0xb0, 0x94,
- 0x92, 0x38, 0x26, 0xa8, 0xff, 0x5c, 0x86, 0x87, 0x79, 0x01, 0x36, 0x05, 0x75, 0x78, 0x09, 0xdc,
- 0x63, 0x6c, 0x60, 0xeb, 0x83, 0xb4, 0xc2, 0xdb, 0x2f, 0xa9, 0xcf, 0x0f, 0x16, 0xc1, 0x72, 0x86,
- 0xac, 0x17, 0x95, 0x81, 0xa2, 0xef, 0xc6, 0x30, 0x71, 0xb0, 0xbc, 0x07, 0x8f, 0xc6, 0xab, 0x16,
- 0x45, 0xff, 0x9f, 0xca, 0xb0, 0xbc, 0x87, 0x99, 0xe5, 0x5c, 0x6e, 0xf5, 0x9c, 0xe0, 0x7c, 0x32,
- 0x7c, 0xe3, 0x21, 0x5c, 0xeb, 0x52, 0xd2, 0xb7, 0x53, 0x20, 0x47, 0xcd, 0x6a, 0x70, 0xa2, 0xba,
- 0x63, 0xaf, 0x42, 0x9d, 0x11, 0x3b, 0x75, 0x4b, 0xaf, 0x59, 0xc0, 0x88, 0x95, 0x46, 0x42, 0x66,
- 0xcc, 0x7f, 0xcc, 0xc2, 0xcd, 0x11, 0xd5, 0x22, 0x67, 0xec, 0x43, 0x9d, 0x3a, 0x97, 0xb6, 0x2b,
- 0xc9, 0xad, 0xb2, 0x38, 0xc3, 0xde, 0x4f, 0x94, 0xbc, 0xd9, 0x31, 0x6b, 0x8a, 0x64, 0x01, 0x55,
- 0x5c, 0xe3, 0xc7, 0x59, 0xa8, 0x29, 0x0e, 0x5a, 0x81, 0xca, 0x99, 0x4f, 0xce, 0xf8, 0x85, 0x4b,
- 0x06, 0xda, 0x02, 0x6f, 0x1e, 0x74, 0x14, 0x3a, 0x34, 0xa3, 0xd1, 0x21, 0x01, 0x52, 0xe0, 0x4b,
- 0x79, 0xbc, 0xcb, 0x45, 0x54, 0x02, 0x7c, 0xc9, 0x4f, 0x77, 0xce, 0xe2, 0x95, 0x86, 0x60, 0xcd,
- 0x49, 0x16, 0xf1, 0x3b, 0x82, 0x75, 0x04, 0x35, 0x32, 0xc0, 0xd4, 0x61, 0x7c, 0xed, 0xf3, 0xa2,
- 0x56, 0xff, 0xec, 0x1d, 0x15, 0x5f, 0x3b, 0x8a, 0x07, 0x5a, 0x5a, 0x06, 0xb7, 0x39, 0xb7, 0x85,
- 0x16, 0x2a, 0xb1, 0x96, 0x06, 0x75, 0x2e, 0x55, 0xff, 0x58, 0xa1, 0x3e, 0xe9, 0x60, 0x01, 0xb7,
- 0xcc, 0x0b, 0x85, 0x5e, 0x90, 0x8e, 0x5a, 0x86, 0x60, 0x55, 0x25, 0x2b, 0xc0, 0x97, 0x9c, 0x65,
- 0x7a, 0x50, 0xd3, 0x22, 0xea, 0x50, 0x79, 0x79, 0xf8, 0xd5, 0xe1, 0xd1, 0xab, 0xc3, 0x66, 0x09,
- 0xd5, 0x60, 0x7e, 0x63, 0x7b, 0x7b, 0x67, 0x5b, 0x62, 0x04, 0x5b, 0x47, 0xc7, 0x07, 0x3b, 0xdb,
- 0x12, 0x23, 0xd8, 0xde, 0x79, 0xbe, 0x73, 0xba, 0xb3, 0xdd, 0x9c, 0x45, 0x0d, 0xa8, 0xbe, 0x38,
- 0xda, 0x3e, 0xd8, 0xe5, 0xac, 0x39, 0xce, 0xb2, 0x76, 0x0e, 0x37, 0x5e, 0xec, 0x6c, 0x37, 0xe7,
- 0x51, 0x13, 0x1a, 0xa7, 0xbf, 0x3a, 0xde, 0xb1, 0xb7, 0xf6, 0x37, 0x0e, 0xf7, 0x76, 0xb6, 0x9b,
- 0x0b, 0xe6, 0x6f, 0xa1, 0x75, 0x82, 0x1d, 0xea, 0xf6, 0x76, 0x3d, 0x1f, 0x87, 0x9b, 0x57, 0x3c,
- 0x05, 0x4e, 0x12, 0x89, 0xcb, 0x30, 0xff, 0xfd, 0x10, 0x47, 0x55, 0x49, 0xcd, 0x92, 0x8d, 0xb8,
- 0x5e, 0x9c, 0x55, 0xf5, 0xa2, 0x8a, 0xb5, 0xcf, 0xa0, 0x9d, 0x33, 0xbf, 0xbe, 0x8d, 0x75, 0x39,
- 0x59, 0x04, 0x5a, 0xc3, 0x92, 0x0d, 0xf3, 0x2f, 0x65, 0xb8, 0x9d, 0x1a, 0xb3, 0x45, 0x02, 0x86,
- 0x03, 0xf6, 0x33, 0xa8, 0x8d, 0x3e, 0x80, 0xa6, 0xdb, 0x1b, 0x06, 0x17, 0x98, 0x97, 0xb3, 0x52,
- 0xcb, 0x08, 0x96, 0xbb, 0x11, 0xd1, 0x63, 0xe5, 0xd5, 0x0a, 0xaf, 0xe0, 0x4e, 0xbe, 0xb6, 0xd1,
- 0x22, 0x5b, 0x50, 0xe9, 0x3b, 0xcc, 0xed, 0xa9, 0x65, 0xc6, 0x4d, 0x74, 0x17, 0x40, 0x7c, 0xda,
- 0x89, 0x83, 0xb6, 0x26, 0x28, 0xdb, 0x0e, 0x73, 0xd0, 0x7d, 0x68, 0xe0, 0xa0, 0x63, 0x93, 0xae,
- 0x2d, 0x68, 0x11, 0x6c, 0x08, 0x38, 0xe8, 0x1c, 0x75, 0x5f, 0x70, 0x8a, 0xf9, 0xb7, 0x32, 0xdc,
- 0x38, 0xa6, 0x38, 0x42, 0xea, 0xa4, 0x75, 0x72, 0x4b, 0xc8, 0xf2, 0x7f, 0x81, 0x9a, 0x3c, 0x83,
- 0x45, 0x05, 0x88, 0xbc, 0x4b, 0x0d, 0x1a, 0x63, 0x25, 0x4a, 0xc0, 0x53, 0xa8, 0x93, 0xb3, 0xef,
- 0xb0, 0xcb, 0xec, 0x01, 0xbf, 0x6d, 0xce, 0xa6, 0x87, 0x1e, 0x09, 0xd6, 0x31, 0x21, 0xbe, 0x05,
- 0x44, 0x7d, 0x2b, 0x6b, 0x22, 0x68, 0xea, 0x15, 0x45, 0xa9, 0xf4, 0x3b, 0x58, 0x90, 0x38, 0x64,
- 0x5c, 0x00, 0x95, 0x55, 0x01, 0xc4, 0x13, 0x88, 0x38, 0xed, 0xa5, 0x5f, 0xc5, 0x37, 0xfa, 0x02,
- 0xda, 0x2a, 0x8f, 0x13, 0xea, 0xbd, 0x15, 0xfb, 0xcc, 0xee, 0x61, 0xa7, 0x83, 0x69, 0x94, 0x51,
- 0x56, 0xe2, 0xbc, 0xae, 0xf8, 0xfb, 0x82, 0x6d, 0xfe, 0xa1, 0x0c, 0xb7, 0xc4, 0xec, 0xfb, 0xa7,
- 0xa7, 0xc7, 0x93, 0x63, 0xc1, 0xef, 0xa5, 0xb0, 0xe0, 0xfa, 0xfa, 0x75, 0xdd, 0x5f, 0x88, 0x8e,
- 0xb1, 0xe1, 0x04, 0xd8, 0x3b, 0x9b, 0x02, 0x7b, 0x95, 0x61, 0xda, 0xb0, 0x92, 0xd1, 0x4b, 0xda,
- 0x67, 0xfd, 0x77, 0x2d, 0xf1, 0xa6, 0x12, 0xa3, 0xef, 0xf2, 0x11, 0x0a, 0xbd, 0x82, 0xe6, 0xe8,
- 0x8b, 0x10, 0x5a, 0xcd, 0xaa, 0x9b, 0x7a, 0x82, 0x32, 0xee, 0x17, 0x77, 0x88, 0x9c, 0x51, 0x42,
- 0xaf, 0xe3, 0x17, 0x9c, 0xc4, 0xf3, 0x0e, 0x4a, 0x0e, 0xcc, 0x7d, 0x51, 0x32, 0x1e, 0x8c, 0xe9,
- 0xa1, 0x64, 0xef, 0x00, 0xe8, 0x77, 0x1a, 0xd4, 0x4e, 0x0f, 0x49, 0xbc, 0x18, 0x19, 0x46, 0x1e,
- 0x4b, 0x89, 0xf9, 0x1a, 0xae, 0xa7, 0x9f, 0x57, 0xd0, 0x5d, 0x75, 0x16, 0xe4, 0x3d, 0xf8, 0x18,
- 0xf7, 0x8a, 0xd8, 0x49, 0x91, 0xe9, 0x17, 0x0e, 0x2d, 0x32, 0xf7, 0x39, 0x45, 0x8b, 0xcc, 0x7f,
- 0x18, 0x31, 0x4b, 0xe8, 0xd7, 0x80, 0xb2, 0x2f, 0x12, 0x48, 0xd9, 0xa9, 0xf0, 0x89, 0xc4, 0x30,
- 0xc7, 0x75, 0x51, 0xe2, 0xf7, 0xa1, 0x9e, 0xc0, 0xf0, 0x91, 0xb2, 0x58, 0xf6, 0x99, 0xc3, 0xb8,
- 0x9d, 0xcb, 0x53, 0x92, 0x5e, 0x41, 0x73, 0xf4, 0xce, 0xa3, 0x43, 0xa9, 0xe0, 0x41, 0x40, 0x87,
- 0x52, 0x21, 0xb4, 0x5f, 0x42, 0x7b, 0x00, 0x1a, 0xe6, 0xd6, 0xee, 0xce, 0x60, 0xeb, 0xda, 0xdd,
- 0x59, 0x54, 0xdc, 0x2c, 0x7d, 0x5a, 0xe6, 0x1a, 0x8e, 0xc2, 0xd5, 0x5a, 0xc3, 0x02, 0x7c, 0x5c,
- 0x6b, 0x58, 0x84, 0x74, 0xcb, 0x60, 0xcf, 0xe0, 0xbe, 0x3a, 0xd8, 0x8b, 0xf0, 0x6e, 0x1d, 0xec,
- 0x85, 0xa0, 0xb1, 0x59, 0x42, 0x4f, 0x61, 0x6e, 0x37, 0x74, 0x2f, 0xd0, 0x92, 0xea, 0xac, 0xc1,
- 0x62, 0x63, 0x39, 0x4d, 0x54, 0x83, 0x9e, 0x41, 0x35, 0x46, 0x49, 0xd1, 0x4a, 0xdc, 0x67, 0x04,
- 0xf3, 0x35, 0x5a, 0x59, 0x86, 0x12, 0x70, 0x08, 0xd7, 0x52, 0xd0, 0x26, 0xba, 0xa3, 0x66, 0xca,
- 0xc1, 0x58, 0x8d, 0xbb, 0x05, 0xdc, 0xe4, 0x96, 0xd5, 0x50, 0xa3, 0xf6, 0x61, 0x06, 0x10, 0xd5,
- 0x3e, 0xcc, 0x41, 0x26, 0xc5, 0x66, 0xc8, 0xa2, 0x84, 0x7a, 0x33, 0x14, 0xe2, 0x96, 0x7a, 0x33,
- 0x14, 0x83, 0x8c, 0xb1, 0xf8, 0x51, 0x3c, 0x2f, 0x29, 0xbe, 0x00, 0x61, 0x4c, 0x8a, 0x2f, 0x82,
- 0x03, 0xcd, 0x12, 0xf2, 0xb3, 0x0f, 0x63, 0x11, 0xfe, 0x86, 0xde, 0x2b, 0xda, 0x07, 0x69, 0x40,
- 0xd0, 0x78, 0xff, 0x3f, 0xf6, 0x53, 0xb3, 0xbd, 0x80, 0x46, 0x12, 0x77, 0x43, 0xb7, 0xd3, 0x43,
- 0x53, 0xc5, 0xbf, 0x71, 0x27, 0x9f, 0x99, 0xd8, 0x3c, 0x97, 0x60, 0x14, 0x97, 0xf3, 0xe8, 0x83,
- 0x71, 0x7a, 0xa5, 0xa7, 0xfa, 0xf0, 0x5d, 0xba, 0xc6, 0x13, 0x3f, 0x2e, 0xf3, 0x0c, 0x95, 0x00,
- 0xe9, 0x74, 0x86, 0xca, 0x02, 0x85, 0x3a, 0x43, 0xe5, 0xa0, 0x7a, 0x66, 0x09, 0x6d, 0x42, 0x4d,
- 0xc1, 0x55, 0xa8, 0x55, 0x04, 0xba, 0x19, 0xed, 0x1c, 0x8e, 0x92, 0xf1, 0x15, 0x34, 0x92, 0xb0,
- 0x93, 0xb6, 0x6a, 0x0e, 0xe6, 0xa5, 0xad, 0x9a, 0x8b, 0x54, 0xc9, 0xe4, 0xab, 0xa1, 0x8a, 0x44,
- 0xf2, 0xcd, 0x20, 0x22, 0x89, 0xe4, 0x9b, 0xc5, 0x36, 0xcc, 0x12, 0xfa, 0x56, 0xbc, 0x7f, 0xa6,
- 0x71, 0x05, 0x94, 0x7c, 0x86, 0xcc, 0x85, 0x32, 0x74, 0x06, 0x2a, 0x04, 0x25, 0x84, 0xef, 0x5f,
- 0xc3, 0x62, 0x06, 0x20, 0xd0, 0xd2, 0x8b, 0x30, 0x09, 0x2d, 0xbd, 0x10, 0x5d, 0x30, 0x4b, 0xe8,
- 0x17, 0x50, 0x89, 0x7e, 0x3e, 0x40, 0xb7, 0x54, 0xff, 0xd4, 0xbf, 0x0d, 0xc6, 0x4a, 0x86, 0xae,
- 0x46, 0x7f, 0x09, 0xf5, 0x04, 0x5e, 0x80, 0x92, 0x27, 0xc0, 0x08, 0x0e, 0xa0, 0x2d, 0x98, 0x03,
- 0x30, 0x88, 0x55, 0xfe, 0x06, 0xee, 0x8c, 0x2b, 0xda, 0xd1, 0x47, 0xe3, 0x02, 0x77, 0x74, 0xb6,
- 0x8f, 0xdf, 0xad, 0xb3, 0x5a, 0xc8, 0x31, 0x5c, 0x4b, 0x15, 0xa0, 0x3a, 0xe1, 0xe6, 0xe1, 0x03,
- 0x3a, 0xe1, 0xe6, 0x56, 0xad, 0x62, 0x39, 0x18, 0x96, 0xf3, 0x4a, 0x0e, 0xf4, 0x50, 0x87, 0x77,
- 0x61, 0xf9, 0x64, 0x3c, 0x1a, 0xdf, 0x29, 0x31, 0xcd, 0xb7, 0xb0, 0x98, 0xa9, 0xdd, 0x74, 0x6c,
- 0x14, 0x95, 0x95, 0x3a, 0x36, 0x0a, 0x0b, 0x3f, 0x21, 0xdd, 0x06, 0x94, 0x05, 0x58, 0x51, 0xe2,
- 0x96, 0x58, 0x80, 0xf4, 0xea, 0x8c, 0x3c, 0x06, 0x9f, 0xe5, 0xd9, 0xe5, 0x5b, 0x58, 0xcc, 0x60,
- 0xa9, 0x5a, 0xfd, 0x22, 0xf8, 0x56, 0xab, 0x5f, 0x08, 0xc4, 0x0a, 0xf5, 0x9f, 0x41, 0x35, 0x2e,
- 0x54, 0xf4, 0x39, 0x3c, 0x52, 0x8c, 0xe9, 0x73, 0x38, 0x53, 0xd3, 0x94, 0xd0, 0x29, 0xdc, 0x18,
- 0xb9, 0xd0, 0xa3, 0x7b, 0xa9, 0x5b, 0x43, 0xa6, 0x02, 0x31, 0x56, 0x0b, 0xf9, 0xb1, 0xd4, 0xcd,
- 0x4f, 0x5f, 0xf3, 0x3e, 0xbe, 0x73, 0xb6, 0xe6, 0x92, 0xfe, 0x13, 0xf9, 0xf9, 0x09, 0xa1, 0xe7,
- 0x4f, 0xe4, 0xc8, 0x4f, 0xc4, 0x4f, 0x68, 0x4f, 0xce, 0x49, 0xd4, 0x1e, 0x9c, 0x9d, 0x2d, 0x08,
- 0xd2, 0xd3, 0x7f, 0x07, 0x00, 0x00, 0xff, 0xff, 0x40, 0x12, 0xdf, 0xa3, 0xc9, 0x26, 0x00, 0x00,
+ proto.RegisterFile("repository-service.proto", fileDescriptor_repository_service_99ade1ae2bfb8239)
+}
+
+var fileDescriptor_repository_service_99ade1ae2bfb8239 = []byte{
+ // 2698 bytes of a gzipped FileDescriptorProto
+ 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xc4, 0x5a, 0x5b, 0x73, 0xdb, 0xc6,
+ 0xf5, 0xe7, 0x45, 0x12, 0xc9, 0x43, 0xda, 0xa6, 0x56, 0xb2, 0x45, 0xd2, 0x17, 0xd9, 0xb0, 0x27,
+ 0x71, 0x6e, 0x72, 0x22, 0x3f, 0xfc, 0x33, 0xf9, 0xb7, 0xe3, 0xd1, 0x5d, 0x4a, 0x6c, 0x49, 0x81,
+ 0xe4, 0x78, 0xea, 0x49, 0x07, 0x03, 0x81, 0x4b, 0x11, 0x11, 0x88, 0x65, 0x80, 0xa5, 0x15, 0xb9,
+ 0x33, 0x7d, 0xcb, 0x74, 0x3a, 0xd3, 0x87, 0x3c, 0xf5, 0xf2, 0x1d, 0xfa, 0x09, 0xfa, 0x29, 0xfa,
+ 0xde, 0x4f, 0xd0, 0xd7, 0x7e, 0x82, 0xce, 0x5e, 0xb0, 0x0b, 0x10, 0x00, 0xeb, 0x0e, 0x39, 0xe9,
+ 0x1b, 0xf6, 0x9c, 0xdd, 0xb3, 0x67, 0xcf, 0x39, 0x7b, 0x76, 0xcf, 0x6f, 0x01, 0xad, 0x00, 0x0f,
+ 0x49, 0xe8, 0x52, 0x12, 0x5c, 0x7d, 0x12, 0xe2, 0xe0, 0x8d, 0xeb, 0xe0, 0xb5, 0x61, 0x40, 0x28,
+ 0x41, 0x0b, 0xe7, 0x2e, 0xb5, 0xbd, 0xab, 0x4e, 0x23, 0xec, 0xdb, 0x01, 0xee, 0x0a, 0xaa, 0xf1,
+ 0x12, 0x56, 0x4c, 0x35, 0x62, 0xe7, 0x07, 0x37, 0xa4, 0xa1, 0x89, 0xbf, 0x1f, 0xe1, 0x90, 0xa2,
+ 0x75, 0x00, 0x2d, 0xac, 0x55, 0xbc, 0x5f, 0x7c, 0x5c, 0x5f, 0x47, 0x6b, 0x42, 0xca, 0x9a, 0x1e,
+ 0x64, 0xc6, 0x7a, 0x7d, 0xb1, 0xf0, 0xaf, 0x3f, 0x3d, 0x2e, 0x55, 0x4b, 0xc6, 0x3a, 0xb4, 0xd2,
+ 0x62, 0xc3, 0x21, 0xf1, 0x43, 0x8c, 0x6e, 0xc1, 0x02, 0xe6, 0x14, 0x2e, 0xb3, 0x6a, 0xca, 0x96,
+ 0xf1, 0x0d, 0x1f, 0x63, 0x3b, 0x17, 0x07, 0xbe, 0x13, 0xe0, 0x01, 0xf6, 0xa9, 0xed, 0x4d, 0xaf,
+ 0x4b, 0xd1, 0xb8, 0x0d, 0xed, 0x0c, 0xb9, 0x42, 0x19, 0x83, 0xc2, 0xa2, 0x60, 0xee, 0x8e, 0xbc,
+ 0x69, 0x66, 0x43, 0x0f, 0xe1, 0x9a, 0x13, 0x60, 0x9b, 0x62, 0xeb, 0xcc, 0xa5, 0x03, 0x7b, 0xd8,
+ 0x2a, 0xf1, 0xc5, 0x35, 0x04, 0x71, 0x93, 0xd3, 0x94, 0x4a, 0xcb, 0x80, 0xe2, 0xb3, 0x4a, 0x5d,
+ 0x7e, 0x80, 0x9b, 0x7b, 0x76, 0x70, 0x66, 0x9f, 0xe3, 0x2d, 0xe2, 0x79, 0xd8, 0xa1, 0x3f, 0x9b,
+ 0x3e, 0x2d, 0xb8, 0x35, 0x3e, 0xb3, 0xd4, 0xe9, 0x39, 0x5c, 0xdf, 0xf2, 0xb0, 0xed, 0x8f, 0x86,
+ 0xb3, 0x70, 0xc5, 0x22, 0xdc, 0x50, 0xd2, 0xe4, 0x04, 0x27, 0x70, 0x53, 0x0f, 0x3a, 0x71, 0xdf,
+ 0xe2, 0x59, 0x84, 0xdf, 0xc7, 0x70, 0x6b, 0x5c, 0xa8, 0x0c, 0x3e, 0x04, 0x73, 0xa1, 0xfb, 0x16,
+ 0x73, 0x79, 0x65, 0x93, 0x7f, 0x1b, 0x21, 0xb4, 0x37, 0x86, 0x43, 0xef, 0x6a, 0xcf, 0xa5, 0x36,
+ 0xa5, 0x81, 0x7b, 0x36, 0xa2, 0x78, 0x9a, 0x5d, 0x80, 0x3a, 0x50, 0x0d, 0xf0, 0x1b, 0x37, 0x74,
+ 0x89, 0xcf, 0xcd, 0xde, 0x30, 0x55, 0x5b, 0x99, 0xe2, 0x0e, 0x74, 0xb2, 0x26, 0x95, 0x56, 0xf9,
+ 0x43, 0x09, 0xd0, 0x2e, 0xa6, 0x4e, 0xdf, 0xc4, 0x03, 0x42, 0xa7, 0xb1, 0x09, 0xdb, 0x6e, 0x01,
+ 0x17, 0xc2, 0x55, 0xa9, 0x99, 0xb2, 0x85, 0x96, 0x61, 0xbe, 0x47, 0x02, 0x07, 0xb7, 0xca, 0x3c,
+ 0x30, 0x44, 0x03, 0xad, 0x40, 0xc5, 0x27, 0x16, 0xb5, 0xcf, 0xc3, 0xd6, 0x9c, 0xd8, 0x9d, 0x3e,
+ 0x39, 0xb5, 0xcf, 0x43, 0xd4, 0x82, 0x0a, 0x75, 0x07, 0x98, 0x8c, 0x68, 0x6b, 0xfe, 0x7e, 0xf1,
+ 0xf1, 0xbc, 0x19, 0x35, 0xd9, 0x90, 0x30, 0xec, 0x5b, 0x17, 0xf8, 0xaa, 0xb5, 0x20, 0x66, 0x08,
+ 0xc3, 0xfe, 0x57, 0xf8, 0x0a, 0xad, 0x42, 0xfd, 0xc2, 0x27, 0x97, 0xbe, 0xd5, 0x27, 0x6c, 0xb7,
+ 0x57, 0x38, 0x13, 0x38, 0x69, 0x9f, 0x51, 0x50, 0x1b, 0xaa, 0x3e, 0xb1, 0x86, 0xc1, 0xc8, 0xc7,
+ 0xad, 0x1a, 0x9f, 0xad, 0xe2, 0x93, 0x63, 0xd6, 0x8c, 0xcc, 0xf4, 0xe5, 0x5c, 0xb5, 0xda, 0xac,
+ 0x19, 0x37, 0x61, 0x29, 0x61, 0x0d, 0x69, 0xa5, 0x97, 0xb0, 0xb2, 0xc5, 0xc3, 0x39, 0xb6, 0xf4,
+ 0x19, 0x44, 0x69, 0x07, 0x5a, 0x69, 0xb1, 0x72, 0xca, 0xdf, 0x95, 0x60, 0x71, 0x0f, 0xd3, 0x8d,
+ 0xc0, 0xe9, 0xbb, 0x6f, 0xa6, 0xf2, 0xcb, 0x6d, 0xa8, 0x39, 0x64, 0x30, 0x70, 0xa9, 0xe5, 0x76,
+ 0xa5, 0x6b, 0xaa, 0x82, 0x70, 0xd0, 0x65, 0x4e, 0x1b, 0x06, 0xb8, 0xe7, 0xfe, 0xc0, 0xbd, 0x53,
+ 0x33, 0x65, 0x0b, 0x7d, 0x0e, 0x0b, 0x3d, 0x12, 0x0c, 0x6c, 0xca, 0xbd, 0x73, 0x7d, 0xfd, 0x7e,
+ 0x34, 0x49, 0x4a, 0xa7, 0xb5, 0x5d, 0xde, 0xcf, 0x94, 0xfd, 0x59, 0xe0, 0x0f, 0x6d, 0xda, 0xe7,
+ 0xce, 0x6b, 0x98, 0xfc, 0xdb, 0x78, 0x0a, 0x0b, 0xa2, 0x17, 0xaa, 0x40, 0xf9, 0xf5, 0xc1, 0x71,
+ 0xb3, 0xc0, 0x3e, 0x4e, 0x37, 0xcc, 0x66, 0x11, 0x01, 0x2c, 0x9c, 0x6e, 0x98, 0xd6, 0xde, 0xeb,
+ 0x66, 0x09, 0xd5, 0xa1, 0xc2, 0xbe, 0x37, 0x5f, 0xaf, 0x37, 0xcb, 0x6a, 0x8f, 0x3d, 0x06, 0x14,
+ 0x9f, 0x54, 0xef, 0xaf, 0xae, 0x4d, 0x6d, 0x6e, 0x83, 0x86, 0xc9, 0xbf, 0x99, 0x9b, 0xf6, 0xed,
+ 0xf0, 0x39, 0x71, 0x6c, 0x6f, 0x33, 0xb0, 0x7d, 0xa7, 0x8f, 0x67, 0x72, 0xc6, 0x7c, 0x0a, 0xad,
+ 0xb4, 0x58, 0xa9, 0xc6, 0x32, 0xcc, 0xbf, 0xb1, 0xbd, 0x11, 0x96, 0x47, 0x8c, 0x68, 0x18, 0xff,
+ 0x28, 0x42, 0x8b, 0xc7, 0xd1, 0x09, 0x19, 0x05, 0x0e, 0x16, 0xa3, 0xa6, 0xf1, 0xe1, 0x33, 0x58,
+ 0x0c, 0xb9, 0x28, 0x2b, 0x36, 0xb4, 0x94, 0x3b, 0xb4, 0x29, 0x3a, 0x9b, 0x89, 0x2c, 0x2d, 0x05,
+ 0x9c, 0x71, 0x65, 0xb8, 0xbb, 0x1b, 0x66, 0x23, 0x8c, 0x29, 0x88, 0xee, 0x02, 0x50, 0x3b, 0x38,
+ 0xc7, 0xd4, 0x0a, 0x70, 0x8f, 0x3b, 0xbe, 0x61, 0xd6, 0x04, 0xc5, 0xc4, 0x3d, 0x15, 0xb6, 0x4f,
+ 0xa1, 0x9d, 0xb1, 0x38, 0x7d, 0xe8, 0x06, 0x38, 0x1c, 0x79, 0x34, 0x3a, 0x74, 0x45, 0xcb, 0x38,
+ 0x80, 0xfa, 0x6e, 0xe8, 0x5c, 0xcc, 0x62, 0xdb, 0x3c, 0x82, 0x86, 0x10, 0xa5, 0x7d, 0x80, 0x83,
+ 0x80, 0x04, 0x32, 0x16, 0x44, 0xc3, 0xf8, 0x5b, 0x11, 0x6e, 0xbc, 0x0a, 0x5c, 0xb6, 0xb9, 0x7a,
+ 0xd3, 0x98, 0xbe, 0x09, 0x65, 0x66, 0x0d, 0x91, 0x5e, 0xd9, 0x67, 0x22, 0xeb, 0x96, 0x93, 0x59,
+ 0x17, 0x3d, 0x80, 0x06, 0xf1, 0xba, 0x96, 0xe2, 0x0b, 0x23, 0xd6, 0x89, 0xd7, 0x35, 0xa3, 0x2e,
+ 0x2a, 0x1f, 0xce, 0xc7, 0xf2, 0x61, 0x2c, 0x0f, 0x2d, 0x34, 0x2b, 0x46, 0x0b, 0x9a, 0x5a, 0x77,
+ 0xb1, 0xcc, 0x2f, 0xe7, 0xaa, 0xc5, 0x66, 0xc9, 0x18, 0xc2, 0xf2, 0xae, 0xeb, 0x77, 0x5f, 0xe0,
+ 0xe0, 0x1c, 0x6f, 0xda, 0xe1, 0x54, 0x99, 0xe1, 0x0e, 0xd4, 0x22, 0x45, 0xc3, 0x56, 0xe9, 0x7e,
+ 0x99, 0xb9, 0x5b, 0x11, 0x54, 0xf8, 0x7f, 0x04, 0x37, 0xc7, 0x66, 0xd4, 0x5b, 0xf0, 0xcc, 0x0e,
+ 0x45, 0xe8, 0xd7, 0x4c, 0xfe, 0x6d, 0xfc, 0x54, 0x84, 0x45, 0x91, 0xd3, 0x76, 0x49, 0x70, 0xf1,
+ 0xbf, 0x0c, 0xf9, 0xf8, 0x1d, 0x28, 0xae, 0x91, 0xba, 0x8f, 0xb5, 0x0f, 0x42, 0x13, 0x33, 0xa5,
+ 0x0f, 0xfc, 0xe3, 0x80, 0x9c, 0x07, 0x38, 0x0c, 0xa7, 0x4c, 0xb3, 0x01, 0x17, 0x17, 0x4b, 0xb3,
+ 0x82, 0x70, 0xd0, 0x55, 0xb6, 0xfc, 0x25, 0x74, 0xb2, 0x66, 0x95, 0x06, 0x5d, 0x85, 0xba, 0xeb,
+ 0x5b, 0x43, 0x49, 0x96, 0x1b, 0x08, 0x5c, 0xd5, 0x51, 0x28, 0x7d, 0xf2, 0xfd, 0xc8, 0x0e, 0xfb,
+ 0x33, 0x53, 0x3a, 0xe4, 0xe2, 0x62, 0x4a, 0x0b, 0xc2, 0xb8, 0xd2, 0xe9, 0x59, 0xdf, 0x55, 0x69,
+ 0x1f, 0xee, 0x8d, 0x9f, 0x72, 0xbb, 0x01, 0x19, 0xbc, 0x34, 0x9f, 0x4f, 0xb9, 0x2d, 0x47, 0x81,
+ 0x27, 0x75, 0x66, 0x9f, 0xca, 0xdf, 0x0f, 0x60, 0x35, 0x77, 0x3e, 0xe9, 0xfc, 0xaf, 0x61, 0x49,
+ 0x74, 0xd9, 0x1c, 0xf9, 0x5d, 0x6f, 0x26, 0x37, 0xc1, 0x0f, 0x61, 0x39, 0x29, 0x72, 0xc2, 0x39,
+ 0x35, 0x00, 0xc4, 0x77, 0xf7, 0x16, 0xf1, 0x7b, 0xee, 0xf9, 0x94, 0xfe, 0xeb, 0x8d, 0x3c, 0xcf,
+ 0xe2, 0x27, 0xae, 0xf4, 0x1f, 0x23, 0x1c, 0xdb, 0xb4, 0xaf, 0x0c, 0xf2, 0x11, 0x2c, 0x25, 0xa6,
+ 0x9b, 0x98, 0x36, 0x7f, 0x2a, 0x41, 0xf3, 0x04, 0xd3, 0xe9, 0x55, 0xfb, 0x1c, 0x2a, 0xd8, 0xa7,
+ 0x81, 0x8b, 0x45, 0x6a, 0xa9, 0xaf, 0xdf, 0x8b, 0x06, 0x8c, 0x8b, 0x5f, 0xdb, 0xf1, 0x69, 0x70,
+ 0x65, 0x46, 0xdd, 0x3b, 0x3f, 0x16, 0x61, 0x9e, 0x93, 0x98, 0x93, 0xd9, 0x6d, 0x4f, 0x24, 0x18,
+ 0xf6, 0x89, 0xee, 0x42, 0x8d, 0x1f, 0xb1, 0x56, 0x48, 0x03, 0xb1, 0xe0, 0xfd, 0x82, 0x59, 0xe5,
+ 0xa4, 0x13, 0x1a, 0xa0, 0x07, 0x50, 0x17, 0x6c, 0xd7, 0xa7, 0x4f, 0xd7, 0x79, 0x76, 0x9e, 0xdf,
+ 0x2f, 0x98, 0xc0, 0x89, 0x07, 0x8c, 0x86, 0x56, 0x41, 0xb4, 0xac, 0x33, 0x42, 0x3c, 0x71, 0xf7,
+ 0xdc, 0x2f, 0x98, 0x42, 0xea, 0x26, 0x21, 0xde, 0x66, 0x45, 0x1e, 0xe9, 0xca, 0x7e, 0x4b, 0xb0,
+ 0x18, 0x53, 0x59, 0x86, 0x10, 0x86, 0xa5, 0x6d, 0xec, 0xe1, 0x59, 0x38, 0x11, 0xc1, 0xdc, 0x05,
+ 0xbe, 0x12, 0x66, 0xaa, 0x99, 0xfc, 0x5b, 0xcd, 0x7d, 0x0b, 0x96, 0x93, 0xd3, 0xc8, 0xe9, 0x2f,
+ 0x58, 0xad, 0x19, 0x52, 0x12, 0xe0, 0xad, 0x51, 0x48, 0xc9, 0x60, 0x9f, 0x90, 0x8b, 0x70, 0x4a,
+ 0x25, 0x78, 0x9c, 0x96, 0x74, 0x9c, 0xc6, 0x4b, 0x88, 0xac, 0xc9, 0xa4, 0x2a, 0xdf, 0x40, 0x6b,
+ 0xd3, 0x76, 0x2e, 0x46, 0xc3, 0xd9, 0x68, 0xa2, 0x76, 0xd4, 0x13, 0x68, 0x67, 0xc8, 0x9d, 0xb0,
+ 0xad, 0x42, 0x78, 0x90, 0xb5, 0xf1, 0xa7, 0xde, 0xe3, 0x13, 0x6d, 0xf3, 0x08, 0x8c, 0x49, 0x93,
+ 0x4a, 0x1b, 0x1d, 0x03, 0x62, 0x67, 0xe8, 0x73, 0xd7, 0xc1, 0x7e, 0x38, 0x93, 0x7c, 0xb3, 0x05,
+ 0x4b, 0x09, 0x89, 0xd2, 0x2e, 0x1f, 0x03, 0xf2, 0x04, 0xc9, 0x0a, 0xfb, 0x24, 0xa0, 0x96, 0x6f,
+ 0x0f, 0xa2, 0x13, 0xba, 0x29, 0x39, 0x27, 0x8c, 0x71, 0x68, 0x0f, 0xb8, 0xeb, 0xf6, 0x30, 0x3d,
+ 0xf0, 0x7b, 0x64, 0x63, 0x16, 0xf5, 0xa8, 0x52, 0xee, 0xff, 0xa1, 0x9d, 0x21, 0x57, 0xaa, 0x78,
+ 0x0f, 0x40, 0x17, 0xa2, 0xd2, 0x81, 0x31, 0x0a, 0x53, 0x6a, 0xcb, 0xf6, 0x9c, 0x91, 0x67, 0x53,
+ 0xbc, 0xd5, 0xc7, 0xce, 0x45, 0x38, 0x1a, 0xcc, 0x42, 0xa9, 0xff, 0x83, 0x76, 0x86, 0x5c, 0xa9,
+ 0x54, 0x07, 0xaa, 0x8e, 0xa4, 0x49, 0x6b, 0xa9, 0x36, 0x73, 0xde, 0x1e, 0xa6, 0x27, 0xbe, 0x3d,
+ 0x0c, 0xfb, 0x84, 0xce, 0x42, 0x95, 0x0f, 0x60, 0x29, 0x21, 0x71, 0x42, 0x50, 0xff, 0xa5, 0x08,
+ 0x0f, 0xb3, 0x02, 0x6c, 0x06, 0xea, 0xb0, 0xb2, 0xb8, 0x4f, 0xe9, 0xd0, 0xd2, 0x07, 0x69, 0x85,
+ 0xb5, 0x5f, 0x06, 0x1e, 0x3b, 0x58, 0x38, 0xcb, 0x1e, 0xd1, 0xbe, 0x2c, 0x0d, 0x79, 0xdf, 0x8d,
+ 0x51, 0xec, 0x60, 0x79, 0x0f, 0x1e, 0x4d, 0x56, 0x4d, 0x46, 0xff, 0x9f, 0x8b, 0xb0, 0xbc, 0x87,
+ 0xa9, 0x69, 0x5f, 0x6e, 0xf5, 0x6d, 0xff, 0x7c, 0x3a, 0xcc, 0xe3, 0x21, 0x5c, 0xeb, 0x05, 0x64,
+ 0x60, 0x25, 0x80, 0x8f, 0x9a, 0xd9, 0x60, 0x44, 0x75, 0xc7, 0x5e, 0x85, 0x3a, 0x25, 0x56, 0xe2,
+ 0x96, 0x5e, 0x33, 0x81, 0x12, 0x33, 0x89, 0x8e, 0x94, 0x8c, 0x7f, 0x96, 0xe1, 0xe6, 0x98, 0x6a,
+ 0xd2, 0x19, 0xfb, 0x50, 0x0f, 0xec, 0x4b, 0xcb, 0x11, 0xe4, 0x56, 0x91, 0x9f, 0x61, 0xef, 0xc7,
+ 0xca, 0xe0, 0xf4, 0x98, 0x35, 0x45, 0x32, 0x21, 0x50, 0xdc, 0xce, 0x8f, 0x65, 0xa8, 0x29, 0x0e,
+ 0x5a, 0x81, 0xca, 0x99, 0x47, 0xce, 0xd8, 0x85, 0x4b, 0x04, 0xda, 0x02, 0x6b, 0x1e, 0x74, 0x15,
+ 0x62, 0x54, 0xd2, 0x88, 0x11, 0x07, 0x2e, 0xf0, 0xa5, 0x38, 0xde, 0xc5, 0x22, 0x2a, 0x3e, 0xbe,
+ 0x64, 0xa7, 0x3b, 0x63, 0xb1, 0x4a, 0x83, 0xb3, 0xe6, 0x04, 0x8b, 0x78, 0x5d, 0xce, 0x3a, 0x82,
+ 0x1a, 0x19, 0xe2, 0xc0, 0xa6, 0x6c, 0xed, 0xf3, 0xbc, 0x7e, 0xff, 0xec, 0x1d, 0x15, 0x5f, 0x3b,
+ 0x8a, 0x06, 0x9a, 0x5a, 0x06, 0xb3, 0x39, 0xb3, 0x85, 0x16, 0x2a, 0xf0, 0x97, 0x46, 0x60, 0x5f,
+ 0xaa, 0xfe, 0x91, 0x42, 0x03, 0xd2, 0xc5, 0x1c, 0x82, 0x99, 0xe7, 0x0a, 0xbd, 0x20, 0x5d, 0xb5,
+ 0x0c, 0xce, 0xaa, 0x0a, 0x96, 0x8f, 0x2f, 0x19, 0xcb, 0x70, 0xa1, 0xa6, 0x45, 0xd4, 0xa1, 0xf2,
+ 0xf2, 0xf0, 0xab, 0xc3, 0xa3, 0x57, 0x87, 0xcd, 0x02, 0xaa, 0xc1, 0xfc, 0xc6, 0xf6, 0xf6, 0xce,
+ 0xb6, 0xc0, 0x08, 0xb6, 0x8e, 0x8e, 0x0f, 0x76, 0xb6, 0x05, 0x46, 0xb0, 0xbd, 0xf3, 0x7c, 0xe7,
+ 0x74, 0x67, 0xbb, 0x59, 0x46, 0x0d, 0xa8, 0xbe, 0x38, 0xda, 0x3e, 0xd8, 0x65, 0xac, 0x39, 0xc6,
+ 0x32, 0x77, 0x0e, 0x37, 0x5e, 0xec, 0x6c, 0x37, 0xe7, 0x51, 0x13, 0x1a, 0xa7, 0xbf, 0x3a, 0xde,
+ 0xb1, 0xb6, 0xf6, 0x37, 0x0e, 0xf7, 0x76, 0xb6, 0x9b, 0x0b, 0xc6, 0x6f, 0xa1, 0x75, 0x82, 0xed,
+ 0xc0, 0xe9, 0xef, 0xba, 0x1e, 0x0e, 0x37, 0xaf, 0x58, 0x0a, 0x9c, 0x26, 0x12, 0x97, 0x61, 0xfe,
+ 0xfb, 0x11, 0x96, 0x55, 0x49, 0xcd, 0x14, 0x8d, 0xa8, 0x5e, 0x2c, 0xab, 0x7a, 0x51, 0xc5, 0xda,
+ 0x67, 0xd0, 0xce, 0x98, 0x5f, 0xdf, 0xc6, 0x7a, 0x8c, 0xcc, 0x03, 0xad, 0x61, 0x8a, 0x86, 0xf1,
+ 0xd7, 0x22, 0xdc, 0x4e, 0x8c, 0xd9, 0x22, 0x3e, 0xc5, 0x3e, 0xfd, 0x19, 0xd4, 0x46, 0x1f, 0x40,
+ 0xd3, 0xe9, 0x8f, 0xfc, 0x0b, 0xcc, 0xca, 0x59, 0xa1, 0xa5, 0x84, 0xea, 0x6e, 0x48, 0x7a, 0xa4,
+ 0xbc, 0x5a, 0xe1, 0x15, 0xdc, 0xc9, 0xd6, 0x56, 0x2e, 0xb2, 0x05, 0x95, 0x81, 0x4d, 0x9d, 0xbe,
+ 0x5a, 0x66, 0xd4, 0x44, 0x77, 0x01, 0xf8, 0xa7, 0x15, 0x3b, 0x68, 0x6b, 0x9c, 0xb2, 0x6d, 0x53,
+ 0x1b, 0xdd, 0x87, 0x06, 0xf6, 0xbb, 0x16, 0xe9, 0x59, 0x9c, 0x26, 0xa1, 0x44, 0xc0, 0x7e, 0xf7,
+ 0xa8, 0xf7, 0x82, 0x51, 0x8c, 0xbf, 0x17, 0xe1, 0xc6, 0x71, 0x80, 0x25, 0x7a, 0x27, 0xac, 0x93,
+ 0x59, 0x42, 0x16, 0xff, 0x0b, 0xd4, 0xe4, 0x19, 0x2c, 0x2a, 0x40, 0xe4, 0x5d, 0x6a, 0xd0, 0x08,
+ 0x2b, 0x51, 0x02, 0x9e, 0x42, 0x9d, 0x9c, 0x7d, 0x87, 0x1d, 0x6a, 0x0d, 0xd9, 0x6d, 0xb3, 0x9c,
+ 0x1c, 0x7a, 0xc4, 0x59, 0xc7, 0x84, 0x78, 0x26, 0x10, 0xf5, 0xad, 0xac, 0x89, 0xa0, 0xa9, 0x57,
+ 0x24, 0x53, 0xe9, 0x77, 0xb0, 0x20, 0xb0, 0xc9, 0xa8, 0x00, 0x2a, 0xaa, 0x02, 0x88, 0x25, 0x10,
+ 0x7e, 0xda, 0x0b, 0xbf, 0xf2, 0x6f, 0xf4, 0x05, 0xb4, 0x55, 0x1e, 0x27, 0x81, 0xfb, 0x96, 0xef,
+ 0x33, 0xab, 0x8f, 0xed, 0x2e, 0x0e, 0x64, 0x46, 0x59, 0x89, 0xf2, 0xba, 0xe2, 0xef, 0x73, 0xb6,
+ 0xf1, 0xc7, 0x22, 0xdc, 0xe2, 0xb3, 0xef, 0x9f, 0x9e, 0x1e, 0x4f, 0x8f, 0x0f, 0xbf, 0x97, 0xc0,
+ 0x87, 0xeb, 0xeb, 0xd7, 0x75, 0x7f, 0x2e, 0x3a, 0xc2, 0x8b, 0x63, 0x00, 0x70, 0x39, 0x01, 0x00,
+ 0x2b, 0xc3, 0xb4, 0x61, 0x25, 0xa5, 0x97, 0xb0, 0xcf, 0xfa, 0xef, 0x5b, 0xfc, 0x9d, 0x25, 0x42,
+ 0xe4, 0xc5, 0xc3, 0x14, 0x7a, 0x05, 0xcd, 0xf1, 0x57, 0x22, 0xb4, 0x9a, 0x56, 0x37, 0xf1, 0x2c,
+ 0xd5, 0xb9, 0x9f, 0xdf, 0x41, 0x3a, 0xa3, 0x80, 0x5e, 0x47, 0xaf, 0x3a, 0xb1, 0x27, 0x1f, 0x14,
+ 0x1f, 0x98, 0xf9, 0xca, 0xd4, 0x79, 0x30, 0xa1, 0x87, 0x92, 0xbd, 0x03, 0xa0, 0xdf, 0x6e, 0x50,
+ 0x3b, 0x39, 0x24, 0xf6, 0x8a, 0xd4, 0xe9, 0x64, 0xb1, 0x94, 0x98, 0xaf, 0xe1, 0x7a, 0xf2, 0xc9,
+ 0x05, 0xdd, 0x55, 0x67, 0x41, 0xd6, 0x23, 0x50, 0xe7, 0x5e, 0x1e, 0x3b, 0x2e, 0x32, 0xf9, 0xea,
+ 0xa1, 0x45, 0x66, 0x3e, 0xb1, 0x68, 0x91, 0xd9, 0x8f, 0x25, 0x46, 0x01, 0xfd, 0x1a, 0x50, 0xfa,
+ 0x95, 0x02, 0x29, 0x3b, 0xe5, 0x3e, 0x9b, 0x74, 0x8c, 0x49, 0x5d, 0x94, 0xf8, 0x7d, 0xa8, 0xc7,
+ 0x70, 0x7d, 0xa4, 0x2c, 0x96, 0x7e, 0xfa, 0xe8, 0xdc, 0xce, 0xe4, 0x29, 0x49, 0xaf, 0xa0, 0x39,
+ 0x7e, 0xe7, 0xd1, 0xa1, 0x94, 0xf3, 0x48, 0xa0, 0x43, 0x29, 0x17, 0xee, 0x2f, 0xa0, 0x3d, 0x00,
+ 0x0d, 0x73, 0x6b, 0x77, 0xa7, 0xf0, 0x76, 0xed, 0xee, 0x34, 0x2a, 0x6e, 0x14, 0x3e, 0x2d, 0x32,
+ 0x0d, 0xc7, 0xe1, 0x6a, 0xad, 0x61, 0x0e, 0x3e, 0xae, 0x35, 0xcc, 0x43, 0xba, 0x45, 0xb0, 0xa7,
+ 0x70, 0x5f, 0x1d, 0xec, 0x79, 0x78, 0xb7, 0x0e, 0xf6, 0x5c, 0xd0, 0xd8, 0x28, 0xa0, 0xa7, 0x30,
+ 0xb7, 0x1b, 0x3a, 0x17, 0x68, 0x49, 0x75, 0xd6, 0x60, 0x71, 0x67, 0x39, 0x49, 0x54, 0x83, 0x9e,
+ 0x41, 0x35, 0x42, 0x49, 0xd1, 0x4a, 0xd4, 0x67, 0x0c, 0xf3, 0xed, 0xb4, 0xd2, 0x0c, 0x25, 0xe0,
+ 0x10, 0xae, 0x25, 0xa0, 0x4d, 0x74, 0x47, 0xcd, 0x94, 0x81, 0xb1, 0x76, 0xee, 0xe6, 0x70, 0xe3,
+ 0x5b, 0x56, 0x43, 0x8d, 0xda, 0x87, 0x29, 0x40, 0x54, 0xfb, 0x30, 0x03, 0x99, 0xe4, 0x9b, 0x21,
+ 0x8d, 0x12, 0xea, 0xcd, 0x90, 0x8b, 0x5b, 0xea, 0xcd, 0x90, 0x0f, 0x32, 0x46, 0xe2, 0xc7, 0xf1,
+ 0xbc, 0xb8, 0xf8, 0x1c, 0x84, 0x31, 0x2e, 0x3e, 0x0f, 0x0e, 0x34, 0x0a, 0xc8, 0x4b, 0x3f, 0x96,
+ 0x49, 0xfc, 0x0d, 0xbd, 0x97, 0xb7, 0x0f, 0x92, 0x80, 0x60, 0xe7, 0xfd, 0xff, 0xd8, 0x4f, 0xcd,
+ 0xf6, 0x02, 0x1a, 0x71, 0xdc, 0x0d, 0xdd, 0x4e, 0x0e, 0x4d, 0x14, 0xff, 0x9d, 0x3b, 0xd9, 0xcc,
+ 0xd8, 0xe6, 0xb9, 0x84, 0x4e, 0x7e, 0x39, 0x8f, 0x3e, 0x98, 0xa4, 0x57, 0x72, 0xaa, 0x0f, 0xdf,
+ 0xa5, 0x6b, 0x34, 0xf1, 0xe3, 0x22, 0xcb, 0x50, 0x31, 0x90, 0x4e, 0x67, 0xa8, 0x34, 0x50, 0xa8,
+ 0x33, 0x54, 0x06, 0xaa, 0x67, 0x14, 0xd0, 0x26, 0xd4, 0x14, 0x5c, 0x85, 0x5a, 0x79, 0xa0, 0x5b,
+ 0xa7, 0x9d, 0xc1, 0x51, 0x32, 0xbe, 0x82, 0x46, 0x1c, 0x76, 0xd2, 0x56, 0xcd, 0xc0, 0xbc, 0xb4,
+ 0x55, 0x33, 0x91, 0x2a, 0x91, 0x7c, 0x35, 0x54, 0x11, 0x4b, 0xbe, 0x29, 0x44, 0x24, 0x96, 0x7c,
+ 0xd3, 0xd8, 0x86, 0x51, 0x40, 0xdf, 0xf2, 0x37, 0xd1, 0x24, 0xae, 0x80, 0xe2, 0x4f, 0x93, 0x99,
+ 0x50, 0x86, 0xce, 0x40, 0xb9, 0xa0, 0x04, 0xf7, 0xfd, 0x6b, 0x58, 0x4c, 0x01, 0x04, 0x5a, 0x7a,
+ 0x1e, 0x26, 0xa1, 0xa5, 0xe7, 0xa2, 0x0b, 0x46, 0x01, 0xfd, 0x02, 0x2a, 0xf2, 0x87, 0x04, 0x74,
+ 0x4b, 0xf5, 0x4f, 0xfc, 0xef, 0xd0, 0x59, 0x49, 0xd1, 0xd5, 0xe8, 0x2f, 0xa1, 0x1e, 0xc3, 0x0b,
+ 0x50, 0xfc, 0x04, 0x18, 0xc3, 0x01, 0xb4, 0x05, 0x33, 0x00, 0x06, 0xbe, 0xca, 0xdf, 0xc0, 0x9d,
+ 0x49, 0x45, 0x3b, 0xfa, 0x68, 0x52, 0xe0, 0x8e, 0xcf, 0xf6, 0xf1, 0xbb, 0x75, 0x56, 0x0b, 0x39,
+ 0x86, 0x6b, 0x89, 0x02, 0x54, 0x27, 0xdc, 0x2c, 0x7c, 0x40, 0x27, 0xdc, 0xcc, 0xaa, 0x95, 0x2f,
+ 0x07, 0xc3, 0x72, 0x56, 0xc9, 0x81, 0x1e, 0xea, 0xf0, 0xce, 0x2d, 0x9f, 0x3a, 0x8f, 0x26, 0x77,
+ 0x8a, 0x4d, 0xf3, 0x2d, 0x2c, 0xa6, 0x6a, 0x37, 0x1d, 0x1b, 0x79, 0x65, 0xa5, 0x8e, 0x8d, 0xdc,
+ 0xc2, 0x8f, 0x4b, 0xb7, 0x00, 0xa5, 0x01, 0x56, 0x14, 0xbb, 0x25, 0xe6, 0x20, 0xbd, 0x3a, 0x23,
+ 0x4f, 0xc0, 0x67, 0x59, 0x76, 0xf9, 0x16, 0x16, 0x53, 0x58, 0xaa, 0x56, 0x3f, 0x0f, 0xbe, 0xd5,
+ 0xea, 0xe7, 0x02, 0xb1, 0x5c, 0xfd, 0x67, 0x50, 0x8d, 0x0a, 0x15, 0x7d, 0x0e, 0x8f, 0x15, 0x63,
+ 0xfa, 0x1c, 0x4e, 0xd5, 0x34, 0x05, 0x74, 0x0a, 0x37, 0xc6, 0x2e, 0xf4, 0xe8, 0x5e, 0xe2, 0xd6,
+ 0x90, 0xaa, 0x40, 0x3a, 0xab, 0xb9, 0xfc, 0x48, 0xea, 0xe6, 0xa7, 0xaf, 0x59, 0x1f, 0xcf, 0x3e,
+ 0x5b, 0x73, 0xc8, 0xe0, 0x89, 0xf8, 0xfc, 0x84, 0x04, 0xe7, 0x4f, 0xc4, 0xc8, 0x4f, 0xf8, 0x8f,
+ 0x69, 0x4f, 0xce, 0x89, 0x6c, 0x0f, 0xcf, 0xce, 0x16, 0x38, 0xe9, 0xe9, 0xbf, 0x03, 0x00, 0x00,
+ 0xff, 0xff, 0x8e, 0xfa, 0x34, 0xf8, 0xdd, 0x26, 0x00, 0x00,
}
diff --git a/vendor/vendor.json b/vendor/vendor.json
index 8752b72f6..6a063e103 100644
--- a/vendor/vendor.json
+++ b/vendor/vendor.json
@@ -485,12 +485,12 @@
"revisionTime": "2018-11-02T16:30:54Z"
},
{
- "checksumSHA1": "m2dWxzpWjVu9FT9sNBTEEyCeAYE=",
+ "checksumSHA1": "0SRNhL8pjnvbTuxsGBM0a1KECl4=",
"path": "gitlab.com/gitlab-org/gitaly-proto/go/gitalypb",
- "revision": "16718ac6db9f02a58c5ffa510ba30cf2494eb84e",
- "revisionTime": "2019-03-19T15:35:05Z",
- "version": "v1.18.0",
- "versionExact": "v1.18.0"
+ "revision": "a78297381af20d4ac7108c07c09539ae70ebf074",
+ "revisionTime": "2019-03-27T06:54:18Z",
+ "version": "v1.19.0",
+ "versionExact": "v1.19.0"
},
{
"checksumSHA1": "WMOuBgCyclqy+Mqunb0NbykaC4Y=",
diff --git a/internal/helper/error.go b/internal/helper/error.go
index 81975315d..41bb907b2 100644
--- a/internal/helper/error.go
+++ b/internal/helper/error.go
@@ -1,6 +1,8 @@
package helper
import (
+ "fmt"
+
"google.golang.org/grpc/codes"
"google.golang.org/grpc/status"
)
@@ -20,12 +22,22 @@ func DecorateError(code codes.Code, err error) error {
// ErrInternal wrappes err with codes.Internal, unless err is already a grpc error
func ErrInternal(err error) error { return DecorateError(codes.Internal, err) }
-// ErrInvalidArgument wrappes err with codes.InvalidArgument, unless err is already a grpc error
+// ErrInvalidArgument wraps err with codes.InvalidArgument, unless err is already a grpc error
func ErrInvalidArgument(err error) error { return DecorateError(codes.InvalidArgument, err) }
-// ErrPreconditionFailed wraps error with codes.FailedPrecondition, unless err is already a grpc error
+// ErrInvalidArgumentf wraps err with codes.InvalidArgument, unless err is already a grpc error
+func ErrInvalidArgumentf(format string, a ...interface{}) error {
+ return DecorateError(codes.InvalidArgument, fmt.Errorf(format, a...))
+}
+
+// ErrPreconditionFailed wraps err with codes.FailedPrecondition, unless err is already a grpc error
func ErrPreconditionFailed(err error) error { return DecorateError(codes.FailedPrecondition, err) }
+// ErrPreconditionFailedf wraps err with codes.FailedPrecondition, unless err is already a grpc error
+func ErrPreconditionFailedf(format string, a ...interface{}) error {
+ return DecorateError(codes.FailedPrecondition, fmt.Errorf(format, a...))
+}
+
// ErrNotFound wraps error with codes.NotFound, unless err is already a grpc error
func ErrNotFound(err error) error { return DecorateError(codes.NotFound, err) }